@@ -23,7 +23,7 @@
 #include "ipa_kdb.h"
 #include <unicase.h>
 
-static struct timeval std_timeout = {300, 0};
+static struct timeval std_timeout = {30, 0};
 
 char *ipadb_filter_escape(const char *input, bool star)
 {
@@ -158,12 +158,75 @@ static bool ipadb_need_retry(struct ipadb_context *ipactx, int error)
     return false;
 }
 
+static char *no_attrs[] = {
+    LDAP_NO_ATTRS,
+
+    NULL
+};
+
+static int
+should_support_pac_tkt_sign(struct ipadb_context *ipactx, bool *result)
+{
+    int ret;
+    LDAPMessage *res = NULL;
+    char *masters_dn = NULL;
+    int count;
+
+    char *kdc_filter = "(&(cn=KDC)(objectClass=ipaConfigObject)"
+                       "(!(ipaConfigString=pacTktSignSupported)))";
+
+    if (!ipactx) {
+        ret = KRB5_KDB_DBNOTINITED;
+        goto done;
+    }
+
+    count = asprintf(&masters_dn, "cn=masters,cn=ipa,cn=etc,%s", ipactx->base);
+    if (count < 0) {
+        ret = ENOMEM;
+        goto done;
+    }
+
+    ret = ipadb_simple_search(ipactx, masters_dn, LDAP_SCOPE_SUBTREE,
+                               kdc_filter, no_attrs, &res);
+    if (ret)
+        goto done;
+
+    count = ldap_count_entries(ipactx->lcontext, res);
+
+    if (result)
+        *result = (count == 0);
+
+done:
+    free(masters_dn);
+    ldap_msgfree(res);
+    return ret;
+}
+
 static int ipadb_check_connection(struct ipadb_context *ipactx)
 {
+    int ret = 0;
+
     if (ipactx->lcontext == NULL) {
-        return ipadb_get_connection(ipactx);
+        ret = ipadb_get_connection(ipactx);
     }
-    return 0;
+    if ((ret == 0) && (ipactx->optional_pac_tkt_chksum == IPADB_TRISTATE_UNDEFINED)) {
+        bool pac_tkt_sign_supported;
+
+	/* Enforce PAC ticket signature verification if supported by all KDCs
+	 * To avoid loops as all search functions call into
+	 * ipadb_check_connection(), mark that the init is complete at this
+	 * point. Default to not issuing PAC to be safe.
+         */
+        ipactx->optional_pac_tkt_chksum = IPADB_TRISTATE_FALSE;
+	ret = should_support_pac_tkt_sign(ipactx,
+                                          &pac_tkt_sign_supported);
+        if (ret == 0) {
+            ipactx->optional_pac_tkt_chksum = !pac_tkt_sign_supported;
+        } else {
+            ipactx->optional_pac_tkt_chksum = IPADB_TRISTATE_UNDEFINED;
+	}
+    }
+    return ret;
 }
 
 krb5_error_code ipadb_simple_search(struct ipadb_context *ipactx,
@@ -524,25 +587,11 @@ int ipadb_ldap_attr_to_krb5_timestamp(LDAP *lcontext, LDAPMessage *le,
                                       char *attrname, krb5_timestamp *result)
 {
     time_t res_time;
-    long long res_long;
 
     int ret = ipadb_ldap_attr_to_time_t(lcontext, le,
                                         attrname, &res_time);
     if (ret) return ret;
-
-    /* this will cast correctly maintaing sign to a 64bit variable */
-    res_long = res_time;
-
-    /* For dates beyond IPAPWD_END_OF_TIME, rest_time might oveflow
-     * on 32-bit platforms. This does not apply for 64-bit platforms.
-     * However, since krb5 uses 32-bit time representation, we need
-     * to limit the result.*/
-
-    if (res_long < 0 || res_long > IPAPWD_END_OF_TIME)  {
-        *result = IPAPWD_END_OF_TIME; // 1 Jan 2038, 00:00 GMT
-    } else {
-        *result = (krb5_timestamp)res_long;
-    }
+    *result = (krb5_timestamp)res_time;
 
     return 0;
 }
@@ -610,3 +659,111 @@ done:
     ldap_controls_free(ctrls);
     return ret;
 }
+
+struct ipadb_multires {
+    LDAP *lcontext;
+    LDAPMessage **res;
+    LDAPMessage *next;
+    ssize_t cursor;
+    ssize_t count;
+};
+
+krb5_error_code ipadb_multires_init(LDAP *lcontext, struct ipadb_multires **r)
+{
+    *r = malloc(sizeof(struct ipadb_multires));
+    if (!*r) return ENOMEM;
+    (*r)->lcontext = lcontext;
+    (*r)->res = NULL;
+    (*r)->next = NULL;
+    (*r)->cursor = -1;
+    (*r)->count = 0;
+
+    return 0;
+}
+
+void ipadb_multires_free(struct ipadb_multires *r)
+{
+    if (r != NULL) {
+        for (int i = 0; i < r->count; i++) {
+            ldap_msgfree(r->res[i]);
+        }
+        free(r);
+    }
+}
+
+LDAPMessage *ipadb_multires_next_entry(struct ipadb_multires *r)
+{
+    if (r->count == 0) return NULL;
+
+    if (r->next) {
+        r->next = ldap_next_entry(r->lcontext, r->next);
+    }
+    if (r->next == NULL) {
+        if (r->cursor >= r->count - 1) {
+            return NULL;
+        }
+        r->cursor++;
+        r->next = ldap_first_entry(r->lcontext, r->res[r->cursor]);
+    }
+
+    return r->next;
+}
+
+krb5_error_code ipadb_multibase_search(struct ipadb_context *ipactx,
+                                       char **basedns, int scope,
+                                       char *filter, char **attrs,
+                                       struct ipadb_multires **res,
+                                       bool any)
+{
+    int ret;
+
+    ret = ipadb_multires_init(ipactx->lcontext, res);
+    if (ret != 0) return ret;
+
+    ret = ipadb_check_connection(ipactx);
+    if (ret != 0) {
+        ipadb_multires_free(*res);
+        *res = NULL;
+        return ipadb_simple_ldap_to_kerr(ret);
+    }
+
+    for (int b = 0; basedns[b]; b++) {
+        LDAPMessage *r;
+        ret = ldap_search_ext_s(ipactx->lcontext, basedns[b], scope,
+                                filter, attrs, 0, NULL, NULL,
+                                &std_timeout, LDAP_NO_LIMIT, &r);
+
+        /* first test if we need to retry to connect */
+        if (ret != 0 &&
+            ipadb_need_retry(ipactx, ret)) {
+            ldap_msgfree(r);
+            ret = ldap_search_ext_s(ipactx->lcontext, basedns[b], scope,
+                                    filter, attrs, 0, NULL, NULL,
+                                    &std_timeout, LDAP_NO_LIMIT, &r);
+        }
+
+        if (ret != 0) break;
+
+        if (ldap_count_entries(ipactx->lcontext, r) > 0) {
+            void *tmp = realloc((*res)->res, (((*res)->count + 1) *
+                                                sizeof(LDAPMessage *)));
+            if (tmp == NULL) {
+                ret = ENOMEM;
+                break;
+            }
+            (*res)->res = tmp;
+            (*res)->res[(*res)->count] = r;
+            (*res)->count++;
+
+            if (any) break;
+        }
+    }
+
+    if (ret != 0) {
+        ipadb_multires_free(*res);
+        *res = NULL;
+    }
+
+    return ipadb_simple_ldap_to_kerr(ret);
+}
+
