@@ -452,7 +452,16 @@ ipa_topo_cfg_host_find(TopoReplica *tconf, char *findhost, int lock)
 
     if (lock) slapi_lock_mutex(tconf->repl_lock);
     for (host=tconf->hosts;host;host=host->next) {
-        if (!strcasecmp(host->hostname,findhost)) {
+        if (host->hostname == NULL) {
+            /* this check is done to avoid a crash,
+             * for which the root cause is not yet known.
+             * Avoid the crash and log an error
+             */
+            slapi_log_error(SLAPI_LOG_FATAL, IPA_TOPO_PLUGIN_SUBSYSTEM,
+                            "ipa_topo_cfg_host_find: found a NULL hostname in host list\n");
+            continue;
+        }
+        if (strcasecmp(host->hostname, findhost) == 0) {
            break;
         }
     }
@@ -519,8 +528,9 @@ ipa_topo_cfg_host_del(Slapi_Entry *hostentry)
 
         slapi_lock_mutex(replica->repl_lock);
         hostnode = replica->hosts;
+        prevnode = NULL;
         while (hostnode) {
-            if (!strcasecmp(hostnode->hostname,delhost)) {
+            if (strcasecmp(hostnode->hostname,delhost) == 0) {
                 /*remove from list and free*/
                 if (prevnode) {
                     prevnode->next = hostnode->next;
@@ -556,9 +566,9 @@ ipa_topo_cfg_replica_segment_find(TopoReplica *replica, char *leftHost, char *ri
     while (segments) {
 
         tsegm = segments->segm;
-        if ( (!strcasecmp(leftHost,tsegm->from) && !strcasecmp(rightHost,tsegm->to) &&
+        if ( ((strcasecmp(leftHost,tsegm->from) == 0) && (strcasecmp(rightHost,tsegm->to) == 0) &&
              (tsegm->direct & dir)) ||
-             (!strcasecmp(leftHost,tsegm->to) && !strcasecmp(rightHost,tsegm->from) &&
+             ((strcasecmp(leftHost,tsegm->to) == 0) && (strcasecmp(rightHost,tsegm->from) == 0) &&
              (tsegm->direct & reverse_dir))) {
            break;
         }
@@ -709,9 +719,9 @@ ipa_topo_cfg_segment_set_visited(TopoReplica *replica, TopoReplicaSegment *vsegm
     segments = replica->repl_segments;
     while (segments) {
         tsegm = segments->segm;
-        if ( (!strcasecmp(leftHost,tsegm->from) && !strcasecmp(rightHost,tsegm->to) &&
+        if ( ((strcasecmp(leftHost,tsegm->from) == 0) && (strcasecmp(rightHost,tsegm->to) == 0) &&
              (tsegm->direct == SEGMENT_BIDIRECTIONAL || tsegm->direct == SEGMENT_LEFT_RIGHT)) ||
-             (!strcasecmp(leftHost,tsegm->to) && !strcasecmp(rightHost,tsegm->from) &&
+             ((strcasecmp(leftHost,tsegm->to) == 0) && (strcasecmp(rightHost,tsegm->from) == 0) &&
              (tsegm->direct == SEGMENT_BIDIRECTIONAL || tsegm->direct == SEGMENT_RIGHT_LEFT))) {
             segments->visited = 1;
             break;
@@ -849,8 +859,8 @@ ipa_topo_cfg_replica_free(TopoReplica *tconf)
         while (host) {
             host_next = host->next;
             slapi_ch_free_string(&host->hostname);
-            host = host_next;
             slapi_ch_free((void **)&host);
+            host = host_next;
         }
         slapi_ch_free((void **)&tconf);
     }
@@ -869,7 +879,7 @@ ipa_topo_cfg_replica_find(char *repl_root, int lock)
 
     tconf = topo_shared_conf.replicas;
     while (tconf) {
-        if (!strcasecmp(repl_root,tconf->repl_root)) {
+        if (strcasecmp(repl_root,tconf->repl_root) == 0) {
            break;
         }
         tconf = tconf->next;
