@@ -158,7 +158,10 @@ return {
                         required: true
                     },
                     'idnssoarname',
-                    'idnssoaserial',
+                    {
+                        name: 'idnssoaserial',
+                        read_only: true
+                    },
                     {
                         name: 'idnssoarefresh',
                         measurement_unit: 'seconds'
@@ -184,12 +187,8 @@ return {
                         measurement_unit: 'seconds'
                     },
                     {
-                        $type: 'radio',
+                        $type: 'checkbox',
                         name: 'idnsallowdynupdate',
-                        options: [
-                            { value: 'TRUE', label: '@i18n:true' },
-                            { value: 'FALSE', label: '@i18n:false' }
-                        ]
                     },
                     {
                         $type: 'textarea',
