@@ -43,6 +43,10 @@ var spec = {
     facets: [
         {
             $type: 'search',
+            tab_label: '@i18n:objects.netgroup.netgroups',
+            facet_groups: [IPA.group.search_facet_group],
+            tabs_in_sidebar: true,
+            disable_facet_tabs: false,
             columns: [
                 'cn',
                 'description'
@@ -53,14 +57,23 @@ var spec = {
             $factory: IPA.netgroup.details_facet,
             command_mode: 'info'
         },
+        {
+            $type: 'association',
+            name: 'member_netgroup',
+            add_title: '@i18n:objects.netgroup.add_netgroups',
+            remove_title: '@i18n:objects.netgroup.remove_netgroups'
+        },
         {
             $type: 'association',
             name: 'memberof_netgroup',
-            associator: IPA.serial_associator
+            associator: IPA.serial_associator,
+            add_title: '@i18n:objects.netgroup.add_into_netgroups',
+            remove_title: '@i18n:objects.netgroup.remove_from_netgroups'
         }
     ],
     standard_association_facets: true,
     adder_dialog: {
+        title: '@i18n:objects.netgroup.add',
         fields: [
             'cn',
             {
@@ -68,6 +81,9 @@ var spec = {
                 name: 'description'
             }
         ]
+    },
+    deleter_dialog: {
+        title: '@i18n:objects.netgroup.remove'
     }
 };
 
@@ -174,8 +190,8 @@ var add_netgroup_details_facet_widgets = function (spec) {
                             name: 'memberuser_user',
                             add_method: 'add_member',
                             remove_method: 'remove_member',
-                            add_title: '@i18n:association.add.member',
-                            remove_title: '@i18n:association.remove.member',
+                            add_title: '@i18n:objects.netgroup.add_users',
+                            remove_title: '@i18n:objects.netgroup.remove_users',
                             columns: [
                                 {
                                     name: 'memberuser_user',
@@ -190,8 +206,8 @@ var add_netgroup_details_facet_widgets = function (spec) {
                             name: 'memberuser_group',
                             add_method: 'add_member',
                             remove_method: 'remove_member',
-                            add_title: '@i18n:association.add.member',
-                            remove_title: '@i18n:association.remove.member',
+                            add_title: '@i18n:objects.netgroup.add_groups',
+                            remove_title: '@i18n:objects.netgroup.remove_groups',
                             columns: [
                                 {
                                     name: 'memberuser_group',
@@ -263,8 +279,8 @@ var add_netgroup_details_facet_widgets = function (spec) {
                             add_method: 'add_member',
                             remove_method: 'remove_member',
                             external: 'externalhost',
-                            add_title: '@i18n:association.add.member',
-                            remove_title: '@i18n:association.remove.member',
+                            add_title: '@i18n:objects.netgroup.add_hosts',
+                            remove_title: '@i18n:objects.netgroup.remove_hosts',
                             columns: [
                                 {
                                     name: 'memberhost_host',
@@ -285,8 +301,8 @@ var add_netgroup_details_facet_widgets = function (spec) {
                             name: 'memberhost_hostgroup',
                             add_method: 'add_member',
                             remove_method: 'remove_member',
-                            add_title: '@i18n:association.add.member',
-                            remove_title: '@i18n:association.remove.member',
+                            add_title: '@i18n:objects.netgroup.add_hostgroups',
+                            remove_title: '@i18n:objects.netgroup.remove_hostgroups',
                             columns: [
                                 {
                                     name: 'memberhost_hostgroup',
@@ -328,4 +344,4 @@ exp.register = function() {
 phases.on('registration', exp.register);
 
 return exp;
-});
\ No newline at end of file
+});
