@@ -150,7 +150,12 @@ return {
                                 {
                                     label: '@i18n:authtype.type_idp',
                                     value: 'idp'
+                                },
+                                {
+                                    label: '@i18n:authtype.type_passkey',
+                                    value: 'passkey'
                                 }
+
                             ],
                             tooltip: {
                                 title: '@mc-opt:service_add:krbprincipalauthind:doc'
