@@ -87,7 +87,11 @@ return {
             ],
             policies: [
                 mod_user.stageuser_sidebar_policy
-            ]
+            ],
+            deleter_dialog: {
+                title: '@i18n:objects.stageuser.remove',
+                $factory: IPA.search_deleter_dialog
+            }
         },
         {
             $type: 'details',
@@ -146,6 +150,30 @@ return {
                             name: 'ipasshpubkey',
                             label: '@i18n:objects.sshkeystore.keys'
                         },
+                        {
+                            $type: 'passkey_multivalued',
+                            name: 'ipapasskey',
+                            item_name: 'passkey',
+                            child_spec: {
+                                $type: 'passkey_row',
+                                data_name: 'passkey'
+                            },
+                            tooltip: {
+                                title: '@mc:user_add_passkey.doc'
+                            }
+                        },
+                        {
+                            $type: 'certmap_multivalued',
+                            name: 'ipacertmapdata',
+                            item_name: 'certmapdata',
+                            child_spec: {
+                                $type: 'non_editable_row',
+                                data_name: 'certmap'
+                            },
+                            tooltip: {
+                                title: '@mc:stageuser_add_certmapdata.doc'
+                            }
+                        },
                         {
                             $type: 'checkboxes',
                             name: 'ipauserauthtype',
@@ -153,7 +181,12 @@ return {
                             options: [
                                 { label: '@i18n:authtype.type_password', value: 'password' },
                                 { label: '@i18n:authtype.type_radius', value: 'radius' },
-                                { label: '@i18n:authtype.type_otp', value: 'otp' }
+                                { label: '@i18n:authtype.type_otp', value: 'otp' },
+                                { label: '@i18n:authtype.type_pkinit', value: 'pkinit' },
+                                { label: '@i18n:authtype.type_hardened', value: 'hardened' },
+                                { label: '@i18n:authtype.type_idp', value: 'idp' },
+                                { label: '@i18n:authtype.type_passkey', value: 'passkey' }
+
                             ],
                             tooltip: '@i18n:authtype.user_tooltip'
                         },
@@ -234,6 +267,7 @@ return {
         }
     ],
     adder_dialog: {
+        title: '@i18n:objects.stageuser.add',
         sections: [
             {
                 fields: [
@@ -317,7 +351,11 @@ stageuser.search_preserved_facet_spec = {
     ],
     policies: [
         mod_user.stageuser_sidebar_policy
-    ]
+    ],
+    deleter_dialog: {
+        title: '@i18n:objects.stageuser.preserved_remove',
+        $factory: IPA.search_deleter_dialog
+    }
 };
 
 mod_user.entity_spec.policies = mod_user.entity_spec.policies || {};
