@@ -208,6 +208,18 @@ return {
                             name: 'ipasshpubkey',
                             label: '@i18n:objects.sshkeystore.keys'
                         },
+                        {
+                            $type: 'passkey_multivalued',
+                            name: 'ipapasskey',
+                            item_name: 'passkey',
+                            child_spec: {
+                                $type: 'passkey_row',
+                                data_name: 'passkey'
+                            },
+                            tooltip: {
+                                title: '@mc:user_add_passkey.doc'
+                            }
+                        },
                         {
                             $type: 'certs',
                             name: 'usercertificate',
@@ -241,7 +253,8 @@ return {
                                 { label: '@i18n:authtype.type_otp', value: 'otp' },
                                 { label: '@i18n:authtype.type_pkinit', value: 'pkinit' },
                                 { label: '@i18n:authtype.type_hardened', value: 'hardened' },
-                                { label: '@i18n:authtype.type_idp', value: 'idp' }
+                                { label: '@i18n:authtype.type_idp', value: 'idp' },
+                                { label: '@i18n:authtype.type_passkey', value: 'passkey' }
                             ],
                             tooltip: {
                                 title: '@i18n:authtype.user_tooltip',
