@@ -19,22 +19,24 @@
 */
 
 define(['dojo/_base/declare',
-        'dojo/_base/lang',
         'dojo/Deferred',
         'dojo/dom-construct',
         'dojo/dom-style',
         'dojo/query',
+        'dojo/topic',
         'dojo/on',
         '../ipa',
         '../auth',
+        '../config',
         '../reg',
         '../FieldBinder',
         '../text',
         '../util',
         './LoginScreenBase'
        ],
-       function(declare, lang, Deferred, construct, dom_style, query, on,
-                IPA, auth, reg, FieldBinder, text, util, LoginScreenBase) {
+       function(declare, Deferred, construct, dom_style, query, topic, on,
+                IPA, auth, config, reg, FieldBinder, text, util,
+                LoginScreenBase) {
 
 
     /**
@@ -61,17 +63,17 @@ define(['dojo/_base/declare',
         render_buttons: function(container) {
             this.cancel_btn_node = IPA.button({
                 name: 'cancel',
-                label: 'Cancel',
+                label: text.get('@i18n:buttons.cancel', "Cancel"),
                 'class': 'btn-default btn-lg',
-                click: lang.hitch(this, this.on_cancel)
+                click: this.on_cancel.bind(this)
             })[0];
             if (this.allow_cancel) {
                 construct.place(this.cancel_btn_node, container);
             }
             this.sync_btn_node = IPA.button({
-                label: text.get('@i18n:password.sync_otp_token', "Sync OTP Token"),
+                label: text.get('@i18n:login.sync_otp_token', "Sync OTP Token"),
                 'class': 'btn-primary btn-lg',
-                click: lang.hitch(this, this.on_confirm)
+                click: this.on_confirm.bind(this)
             })[0];
             construct.place(this.sync_btn_node, container);
         },
@@ -118,7 +120,7 @@ define(['dojo/_base/declare',
             var token = this.get_field('token').get_value()[0];
 
             var p = this.sync_core(user, password, otp1, otp2, token);
-            p.then(lang.hitch(this, function(result) {
+            p.then( function(result) {
                 var msg = this.sync_fail;
                 var evt = 'sync-fail';
                 var type = 'error';
@@ -134,7 +136,7 @@ define(['dojo/_base/declare',
                     val_summary.add_error('sync', msg);
                 }
                 this.emit(evt, { source: this, message: msg, status: result });
-            }));
+            }.bind(this));
         },
 
         sync_core: function(user, password, otp1, otp2, token) {
@@ -151,12 +153,12 @@ define(['dojo/_base/declare',
             var handler = function(data, text_status, xhr) {
                 var result = xhr.getResponseHeader("X-IPA-TokenSync-Result");
                 result = result || 'error';
-                IPA.hide_activity_icon();
+                topic.publish('rpc-end');
                 d.resolve(result);
             };
 
             var request = {
-                url: '/ipa/session/sync_token',
+                url: config.token_sync_url,
                 data: data,
                 contentType: 'application/x-www-form-urlencoded',
                 processData: true,
@@ -166,7 +168,7 @@ define(['dojo/_base/declare',
                 error: handler
             };
 
-            IPA.display_activity_icon();
+            topic.publish('rpc-start');
             $.ajax(request);
             return d.promise;
         },
@@ -237,4 +239,4 @@ define(['dojo/_base/declare',
     ];
 
     return SyncOTPScreen;
-});
\ No newline at end of file
+});
