@@ -95,12 +95,12 @@ class config(Object):
         parameters.Int(
             'ipasearchtimelimit',
             label=_(u'Search time limit'),
-            doc=_(u'Maximum amount of time (seconds) for a search (-1 or 0 is unlimited)'),
+            doc=_(u'Maximum amount of time (seconds) for a search (> 0, or -1 for unlimited)'),
         ),
         parameters.Int(
             'ipasearchrecordslimit',
             label=_(u'Search size limit'),
-            doc=_(u'Maximum number of records to search (-1 or 0 is unlimited)'),
+            doc=_(u'Maximum number of records to search (-1 is unlimited)'),
         ),
         parameters.Str(
             'ipausersearchfields',
@@ -216,14 +216,14 @@ class config_mod(Method):
             required=False,
             cli_name='searchtimelimit',
             label=_(u'Search time limit'),
-            doc=_(u'Maximum amount of time (seconds) for a search (-1 or 0 is unlimited)'),
+            doc=_(u'Maximum amount of time (seconds) for a search (> 0, or -1 for unlimited)'),
         ),
         parameters.Int(
             'ipasearchrecordslimit',
             required=False,
             cli_name='searchrecordslimit',
             label=_(u'Search size limit'),
-            doc=_(u'Maximum number of records to search (-1 or 0 is unlimited)'),
+            doc=_(u'Maximum number of records to search (-1 is unlimited)'),
         ),
         parameters.Str(
             'ipausersearchfields',
@@ -302,7 +302,7 @@ class config_mod(Method):
             required=False,
             multivalue=True,
             cli_name='user_auth_type',
-            cli_metavar="['password', 'radius', 'otp', 'disabled']",
+            cli_metavar="['password', 'radius', 'otp']",
             label=_(u'Default user authentication types'),
             doc=_(u'Default types of supported user authentication'),
         ),
