@@ -28,7 +28,7 @@ EXAMPLES:
    ipa netgroup-add --desc="NFS admins" admins
 
  Add members to the netgroup:
-   ipa netgroup-add-member --users=tuser1,tuser2 admins
+   ipa netgroup-add-member --users=tuser1 --users=tuser2 admins
 
  Remove a member from the netgroup:
    ipa netgroup-remove-member --users=tuser2 admins
@@ -53,6 +53,7 @@ class netgroup(Object):
         ),
         parameters.Str(
             'description',
+            required=False,
             label=_(u'Description'),
             doc=_(u'Netgroup description'),
         ),
@@ -138,6 +139,7 @@ class netgroup_add(Method):
     takes_options = (
         parameters.Str(
             'description',
+            required=False,
             cli_name='desc',
             label=_(u'Description'),
             doc=_(u'Netgroup description'),
@@ -199,6 +201,13 @@ class netgroup_add(Method):
             default=False,
             autofill=True,
         ),
+        parameters.Flag(
+            'no_members',
+            doc=_(u'Suppress processing of membership attributes.'),
+            exclude=('webui', 'cli'),
+            default=False,
+            autofill=True,
+        ),
     )
     has_output = (
         output.Output(
@@ -209,9 +218,8 @@ class netgroup_add(Method):
         output.Entry(
             'result',
         ),
-        output.Output(
+        output.PrimaryKey(
             'value',
-            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
@@ -244,13 +252,20 @@ class netgroup_add_member(Method):
             default=False,
             autofill=True,
         ),
+        parameters.Flag(
+            'no_members',
+            doc=_(u'Suppress processing of membership attributes.'),
+            exclude=('webui', 'cli'),
+            default=False,
+            autofill=True,
+        ),
         parameters.Str(
             'user',
             required=False,
             multivalue=True,
             cli_name='users',
             label=_(u'member user'),
-            doc=_(u'comma-separated list of users to add'),
+            doc=_(u'users to add'),
             alwaysask=True,
         ),
         parameters.Str(
@@ -259,7 +274,7 @@ class netgroup_add_member(Method):
             multivalue=True,
             cli_name='groups',
             label=_(u'member group'),
-            doc=_(u'comma-separated list of groups to add'),
+            doc=_(u'groups to add'),
             alwaysask=True,
         ),
         parameters.Str(
@@ -268,7 +283,7 @@ class netgroup_add_member(Method):
             multivalue=True,
             cli_name='hosts',
             label=_(u'member host'),
-            doc=_(u'comma-separated list of hosts to add'),
+            doc=_(u'hosts to add'),
             alwaysask=True,
         ),
         parameters.Str(
@@ -277,7 +292,7 @@ class netgroup_add_member(Method):
             multivalue=True,
             cli_name='hostgroups',
             label=_(u'member host group'),
-            doc=_(u'comma-separated list of host groups to add'),
+            doc=_(u'host groups to add'),
             alwaysask=True,
         ),
         parameters.Str(
@@ -286,7 +301,7 @@ class netgroup_add_member(Method):
             multivalue=True,
             cli_name='netgroups',
             label=_(u'member netgroup'),
-            doc=_(u'comma-separated list of netgroups to add'),
+            doc=_(u'netgroups to add'),
             alwaysask=True,
         ),
     )
@@ -339,10 +354,8 @@ class netgroup_del(Method):
             dict,
             doc=_(u'List of deletions that failed'),
         ),
-        output.Output(
+        output.ListOfPrimaryKeys(
             'value',
-            unicode,
-            doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
 
@@ -448,6 +461,13 @@ class netgroup_find(Method):
             default=False,
             autofill=True,
         ),
+        parameters.Flag(
+            'no_members',
+            doc=_(u'Suppress processing of membership attributes.'),
+            exclude=('webui', 'cli'),
+            default=False,
+            autofill=True,
+        ),
         parameters.Flag(
             'pkey_only',
             required=False,
@@ -666,6 +686,13 @@ class netgroup_mod(Method):
             default=False,
             autofill=True,
         ),
+        parameters.Flag(
+            'no_members',
+            doc=_(u'Suppress processing of membership attributes.'),
+            exclude=('webui', 'cli'),
+            default=False,
+            autofill=True,
+        ),
     )
     has_output = (
         output.Output(
@@ -676,9 +703,8 @@ class netgroup_mod(Method):
         output.Entry(
             'result',
         ),
-        output.Output(
+        output.PrimaryKey(
             'value',
-            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
@@ -711,13 +737,20 @@ class netgroup_remove_member(Method):
             default=False,
             autofill=True,
         ),
+        parameters.Flag(
+            'no_members',
+            doc=_(u'Suppress processing of membership attributes.'),
+            exclude=('webui', 'cli'),
+            default=False,
+            autofill=True,
+        ),
         parameters.Str(
             'user',
             required=False,
             multivalue=True,
             cli_name='users',
             label=_(u'member user'),
-            doc=_(u'comma-separated list of users to remove'),
+            doc=_(u'users to remove'),
             alwaysask=True,
         ),
         parameters.Str(
@@ -726,7 +759,7 @@ class netgroup_remove_member(Method):
             multivalue=True,
             cli_name='groups',
             label=_(u'member group'),
-            doc=_(u'comma-separated list of groups to remove'),
+            doc=_(u'groups to remove'),
             alwaysask=True,
         ),
         parameters.Str(
@@ -735,7 +768,7 @@ class netgroup_remove_member(Method):
             multivalue=True,
             cli_name='hosts',
             label=_(u'member host'),
-            doc=_(u'comma-separated list of hosts to remove'),
+            doc=_(u'hosts to remove'),
             alwaysask=True,
         ),
         parameters.Str(
@@ -744,7 +777,7 @@ class netgroup_remove_member(Method):
             multivalue=True,
             cli_name='hostgroups',
             label=_(u'member host group'),
-            doc=_(u'comma-separated list of host groups to remove'),
+            doc=_(u'host groups to remove'),
             alwaysask=True,
         ),
         parameters.Str(
@@ -753,7 +786,7 @@ class netgroup_remove_member(Method):
             multivalue=True,
             cli_name='netgroups',
             label=_(u'member netgroup'),
-            doc=_(u'comma-separated list of netgroups to remove'),
+            doc=_(u'netgroups to remove'),
             alwaysask=True,
         ),
     )
@@ -808,6 +841,13 @@ class netgroup_show(Method):
             default=False,
             autofill=True,
         ),
+        parameters.Flag(
+            'no_members',
+            doc=_(u'Suppress processing of membership attributes.'),
+            exclude=('webui', 'cli'),
+            default=False,
+            autofill=True,
+        ),
     )
     has_output = (
         output.Output(
@@ -818,9 +858,8 @@ class netgroup_show(Method):
         output.Entry(
             'result',
         ),
-        output.Output(
+        output.PrimaryKey(
             'value',
-            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
