@@ -16,7 +16,7 @@ from ipapython.dnsutil import DNSName
 if six.PY3:
     unicode = str
 
-__doc__ = _("""
+__doc__ = _(r"""
 Auto Membership Rule.
 
 Bring clarity to the membership of hosts and users by configuring inclusive
@@ -34,8 +34,6 @@ A default group or hostgroup could be specified for entries that do not
 match any rule. In case of user entries this group will be a fallback group
 because all users are by default members of group specified in IPA config.
 
-The automember-rebuild command can be used to retroactively run automember rules
-against existing entries, thus rebuilding their membership.
 
 EXAMPLES:
 
@@ -100,18 +98,6 @@ EXAMPLES:
  Delete an automember rule:
     ipa automember-del --type=hostgroup webservers
     ipa automember-del --type=group devel
-
- Rebuild membership for all users:
-    ipa automember-rebuild --type=group
-
- Rebuild membership for all hosts:
-    ipa automember-rebuild --type=hostgroup
-
- Rebuild membership for specified users:
-    ipa automember-rebuild --users=tuser1 --users=tuser2
-
- Rebuild membership for specified hosts:
-    ipa automember-rebuild --hosts=web1.example.com --hosts=web2.example.com
 """)
 
 register = Registry()
@@ -199,8 +185,9 @@ class automember_add(Method):
         output.Entry(
             'result',
         ),
-        output.PrimaryKey(
+        output.Output(
             'value',
+            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
@@ -277,8 +264,9 @@ class automember_add_condition(Method):
         output.Entry(
             'result',
         ),
-        output.PrimaryKey(
+        output.Output(
             'value',
+            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
         output.Output(
@@ -336,8 +324,9 @@ class automember_default_group_remove(Method):
         output.Entry(
             'result',
         ),
-        output.PrimaryKey(
+        output.Output(
             'value',
+            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
@@ -391,8 +380,9 @@ class automember_default_group_set(Method):
         output.Entry(
             'result',
         ),
-        output.PrimaryKey(
+        output.Output(
             'value',
+            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
@@ -433,8 +423,9 @@ class automember_default_group_show(Method):
         output.Entry(
             'result',
         ),
-        output.PrimaryKey(
+        output.Output(
             'value',
+            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
@@ -471,8 +462,10 @@ class automember_del(Method):
             dict,
             doc=_(u'List of deletions that failed'),
         ),
-        output.ListOfPrimaryKeys(
+        output.Output(
             'value',
+            unicode,
+            doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
 
@@ -617,73 +610,9 @@ class automember_mod(Method):
         output.Entry(
             'result',
         ),
-        output.PrimaryKey(
-            'value',
-            doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
-        ),
-    )
-
-
-@register()
-class automember_rebuild(Command):
-    __doc__ = _("Rebuild auto membership.")
-
-    takes_options = (
-        parameters.Str(
-            'type',
-            required=False,
-            cli_metavar="['group', 'hostgroup']",
-            label=_(u'Rebuild membership for all members of a grouping'),
-            doc=_(u'Grouping to which the rule applies'),
-        ),
-        parameters.Str(
-            'users',
-            required=False,
-            multivalue=True,
-            label=_(u'Users'),
-            doc=_(u'Rebuild membership for specified users'),
-        ),
-        parameters.Str(
-            'hosts',
-            required=False,
-            multivalue=True,
-            label=_(u'Hosts'),
-            doc=_(u'Rebuild membership for specified hosts'),
-        ),
-        parameters.Flag(
-            'no_wait',
-            required=False,
-            label=_(u'No wait'),
-            doc=_(u"Don't wait for rebuilding membership"),
-            default=False,
-            autofill=True,
-        ),
-        parameters.Flag(
-            'all',
-            doc=_(u'Retrieve and print all attributes from the server. Affects command output.'),
-            exclude=('webui',),
-            default=False,
-            autofill=True,
-        ),
-        parameters.Flag(
-            'raw',
-            doc=_(u'Print entries as stored on the server. Only affects output format.'),
-            exclude=('webui',),
-            default=False,
-            autofill=True,
-        ),
-    )
-    has_output = (
         output.Output(
-            'summary',
-            (unicode, type(None)),
-            doc=_(u'User-friendly description of action performed'),
-        ),
-        output.Entry(
-            'result',
-        ),
-        output.PrimaryKey(
             'value',
+            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
@@ -760,8 +689,9 @@ class automember_remove_condition(Method):
         output.Entry(
             'result',
         ),
-        output.PrimaryKey(
+        output.Output(
             'value',
+            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
         output.Output(
@@ -820,8 +750,9 @@ class automember_show(Method):
         output.Entry(
             'result',
         ),
-        output.PrimaryKey(
+        output.Output(
             'value',
+            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
