@@ -20,15 +20,13 @@ __doc__ = _("""
 Permissions
 
 A permission enables fine-grained delegation of rights. A permission is
-a human-readable wrapper around a 389-ds Access Control Rule,
-or instruction (ACI).
+a human-readable form of a 389-ds Access Control Rule, or instruction (ACI).
 A permission grants the right to perform a specific task such as adding a
 user, modifying a group, etc.
 
 A permission may not contain other permissions.
 
-* A permission grants access to read, write, add, delete, read, search,
-  or compare.
+* A permission grants access to read, write, add or delete.
 * A privilege combines similar permissions (for example all the permissions
   needed to add a user).
 * A role grants a set of privileges to users, groups, hosts or hostgroups.
@@ -43,36 +41,25 @@ Rights define what operations are allowed, and may be one or more
 of the following:
 1. write - write one or more attributes
 2. read - read one or more attributes
-3. search - search on one or more attributes
-4. compare - compare one or more attributes
-5. add - add a new entry to the tree
-6. delete - delete an existing entry
-7. all - all permissions are granted
+3. add - add a new entry to the tree
+4. delete - delete an existing entry
+5. all - all permissions are granted
+
+Read permission is granted for most attributes by default so the read
+permission is not expected to be used very often.
 
 Note the distinction between attributes and entries. The permissions are
 independent, so being able to add a user does not mean that the user will
 be editable.
 
 There are a number of allowed targets:
-1. subtree: a DN; the permission applies to the subtree under this DN
-2. target filter: an LDAP filter
-3. target: DN with possible wildcards, specifies entries permission applies to
-
-Additionally, there are the following convenience options.
-Setting one of these options will set the corresponding attribute(s).
-1. type: a type of object (user, group, etc); sets subtree and target filter.
-2. memberof: apply to members of a group; sets target filter
-3. targetgroup: grant access to modify a specific group (such as granting
-   the rights to manage group membership); sets target.
-
-Managed permissions
-
-Permissions that come with IPA by default can be so-called "managed"
-permissions. These have a default set of attributes they apply to,
-but the administrator can add/remove individual attributes to/from the set.
-
-Deleting or renaming a managed permission, as well as changing its target,
-is not allowed.
+1. type: a type of object (user, group, etc).
+2. memberof: a member of a group or hostgroup
+3. filter: an LDAP filter
+4. subtree: an LDAP filter specifying part of the LDAP DIT. This is a
+   super-set of the "type" target.
+5. targetgroup: grant access to modify a specific group (such as granting
+   the rights to manage group membership)
 
 EXAMPLES:
 
@@ -95,117 +82,47 @@ class permission(Object):
             label=_(u'Permission name'),
         ),
         parameters.Str(
-            'ipapermright',
-            required=False,
+            'permissions',
             multivalue=True,
-            label=_(u'Granted rights'),
-            doc=_(u'Rights to grant (read, search, compare, write, add, delete, all)'),
+            label=_(u'Permissions'),
+            doc=_(u'Comma-separated list of permissions to grant (read, write, add, delete, all)'),
         ),
         parameters.Str(
             'attrs',
             required=False,
             multivalue=True,
-            label=_(u'Effective attributes'),
-            doc=_(u'All attributes to which the permission applies'),
-        ),
-        parameters.Str(
-            'ipapermincludedattr',
-            required=False,
-            multivalue=True,
-            label=_(u'Included attributes'),
-            doc=_(u'User-specified attributes to which the permission applies'),
-        ),
-        parameters.Str(
-            'ipapermexcludedattr',
-            required=False,
-            multivalue=True,
-            label=_(u'Excluded attributes'),
-            doc=_(u'User-specified attributes to which the permission explicitly does not apply'),
-        ),
-        parameters.Str(
-            'ipapermdefaultattr',
-            required=False,
-            multivalue=True,
-            label=_(u'Default attributes'),
-            doc=_(u'Attributes to which the permission applies by default'),
-        ),
-        parameters.Str(
-            'ipapermbindruletype',
-            label=_(u'Bind rule type'),
-        ),
-        parameters.Str(
-            'ipapermlocation',
-            required=False,
-            label=_(u'Subtree'),
-            doc=_(u'Subtree to apply permissions to'),
-        ),
-        parameters.Str(
-            'extratargetfilter',
-            required=False,
-            multivalue=True,
-            label=_(u'Extra target filter'),
-        ),
-        parameters.Str(
-            'ipapermtargetfilter',
-            required=False,
-            multivalue=True,
-            label=_(u'Raw target filter'),
-            doc=_(u'All target filters, including those implied by type and memberof'),
-        ),
-        parameters.DNParam(
-            'ipapermtarget',
-            required=False,
-            label=_(u'Target DN'),
-            doc=_(u'Optional DN to apply the permission to (must be in the subtree, but may not yet exist)'),
-        ),
-        parameters.DNParam(
-            'ipapermtargetto',
-            required=False,
-            label=_(u'Target DN subtree'),
-            doc=_(u'Optional DN subtree where an entry can be moved to (must be in the subtree, but may not yet exist)'),
-        ),
-        parameters.DNParam(
-            'ipapermtargetfrom',
-            required=False,
-            label=_(u'Origin DN subtree'),
-            doc=_(u'Optional DN subtree from where an entry can be moved (must be in the subtree, but may not yet exist)'),
-        ),
-        parameters.Str(
-            'memberof',
-            required=False,
-            multivalue=True,
-            label=_(u'Member of group'),
-            doc=_(u'Target members of a group (sets memberOf targetfilter)'),
-        ),
-        parameters.Str(
-            'targetgroup',
-            required=False,
-            label=_(u'Target group'),
-            doc=_(u'User group to apply permissions to (sets target)'),
+            label=_(u'Attributes'),
+            doc=_(u'Comma-separated list of attributes'),
         ),
         parameters.Str(
             'type',
             required=False,
             label=_(u'Type'),
-            doc=_(u'Type of IPA object (sets subtree and objectClass targetfilter)'),
+            doc=_(u'Type of IPA object (user, group, host, hostgroup, service, netgroup, dns)'),
+        ),
+        parameters.Str(
+            'memberof',
+            required=False,
+            label=_(u'Member of group'),
+            doc=_(u'Target members of a group'),
         ),
         parameters.Str(
             'filter',
             required=False,
-            multivalue=True,
-            doc=_(u'Deprecated; use extratargetfilter'),
+            label=_(u'Filter'),
+            doc=_(u'Legal LDAP filter (e.g. ou=Engineering)'),
         ),
         parameters.Str(
             'subtree',
             required=False,
-            multivalue=True,
-            doc=_(u'Deprecated; use ipapermlocation'),
+            label=_(u'Subtree'),
+            doc=_(u'Subtree to apply permissions to'),
         ),
         parameters.Str(
-            'permissions',
+            'targetgroup',
             required=False,
-            multivalue=True,
-            doc=_(u'Deprecated; use ipapermright'),
+            label=_(u'Target group'),
+            doc=_(u'User group to apply permissions to'),
         ),
         parameters.Str(
             'member_privilege',
@@ -233,117 +150,56 @@ class permission_add(Method):
     )
     takes_options = (
         parameters.Str(
-            'ipapermright',
-            required=False,
+            'permissions',
             multivalue=True,
-            cli_name='right',
-            cli_metavar="['read', 'search', 'compare', 'write', 'add', 'delete', 'all']",
-            label=_(u'Granted rights'),
-            doc=_(u'Rights to grant (read, search, compare, write, add, delete, all)'),
-            alwaysask=True,
+            label=_(u'Permissions'),
+            doc=_(u'Comma-separated list of permissions to grant (read, write, add, delete, all)'),
         ),
         parameters.Str(
             'attrs',
             required=False,
             multivalue=True,
-            label=_(u'Effective attributes'),
-            doc=_(u'All attributes to which the permission applies'),
-        ),
-        parameters.Str(
-            'ipapermbindruletype',
-            cli_name='bindtype',
-            cli_metavar="['permission', 'all', 'anonymous']",
-            label=_(u'Bind rule type'),
-            default=u'permission',
-            autofill=True,
-        ),
-        parameters.Str(
-            'ipapermlocation',
-            required=False,
-            cli_name='subtree',
-            label=_(u'Subtree'),
-            doc=_(u'Subtree to apply permissions to'),
+            label=_(u'Attributes'),
+            doc=_(u'Comma-separated list of attributes'),
             alwaysask=True,
+            no_convert=True,
         ),
         parameters.Str(
-            'extratargetfilter',
+            'type',
             required=False,
-            multivalue=True,
-            cli_name='filter',
-            label=_(u'Extra target filter'),
-        ),
-        parameters.Str(
-            'ipapermtargetfilter',
-            required=False,
-            multivalue=True,
-            cli_name='rawfilter',
-            label=_(u'Raw target filter'),
-            doc=_(u'All target filters, including those implied by type and memberof'),
-        ),
-        parameters.DNParam(
-            'ipapermtarget',
-            required=False,
-            cli_name='target',
-            label=_(u'Target DN'),
-            doc=_(u'Optional DN to apply the permission to (must be in the subtree, but may not yet exist)'),
-        ),
-        parameters.DNParam(
-            'ipapermtargetto',
-            required=False,
-            cli_name='targetto',
-            label=_(u'Target DN subtree'),
-            doc=_(u'Optional DN subtree where an entry can be moved to (must be in the subtree, but may not yet exist)'),
-        ),
-        parameters.DNParam(
-            'ipapermtargetfrom',
-            required=False,
-            cli_name='targetfrom',
-            label=_(u'Origin DN subtree'),
-            doc=_(u'Optional DN subtree from where an entry can be moved (must be in the subtree, but may not yet exist)'),
+            cli_metavar="['user', 'group', 'host', 'service', 'hostgroup', 'netgroup', 'dnsrecord']",
+            label=_(u'Type'),
+            doc=_(u'Type of IPA object (user, group, host, hostgroup, service, netgroup, dns)'),
+            alwaysask=True,
         ),
         parameters.Str(
             'memberof',
             required=False,
-            multivalue=True,
             label=_(u'Member of group'),
-            doc=_(u'Target members of a group (sets memberOf targetfilter)'),
+            doc=_(u'Target members of a group'),
+            alwaysask=True,
+        ),
+        parameters.Str(
+            'filter',
+            required=False,
+            label=_(u'Filter'),
+            doc=_(u'Legal LDAP filter (e.g. ou=Engineering)'),
+            alwaysask=True,
+        ),
+        parameters.Str(
+            'subtree',
+            required=False,
+            label=_(u'Subtree'),
+            doc=_(u'Subtree to apply permissions to'),
             alwaysask=True,
         ),
         parameters.Str(
             'targetgroup',
             required=False,
             label=_(u'Target group'),
-            doc=_(u'User group to apply permissions to (sets target)'),
+            doc=_(u'User group to apply permissions to'),
             alwaysask=True,
         ),
-        parameters.Str(
-            'type',
-            required=False,
-            label=_(u'Type'),
-            doc=_(u'Type of IPA object (sets subtree and objectClass targetfilter)'),
-            alwaysask=True,
-        ),
-        parameters.Str(
-            'filter',
-            required=False,
-            multivalue=True,
-            doc=_(u'Deprecated; use extratargetfilter'),
-            exclude=('cli', 'webui'),
-        ),
-        parameters.Str(
-            'subtree',
-            required=False,
-            multivalue=True,
-            doc=_(u'Deprecated; use ipapermlocation'),
-            exclude=('cli', 'webui'),
-        ),
-        parameters.Str(
-            'permissions',
-            required=False,
-            multivalue=True,
-            doc=_(u'Deprecated; use ipapermright'),
-            exclude=('cli', 'webui'),
-        ),
         parameters.Str(
             'setattr',
             required=False,
@@ -372,13 +228,6 @@ class permission_add(Method):
             default=False,
             autofill=True,
         ),
-        parameters.Flag(
-            'no_members',
-            doc=_(u'Suppress processing of membership attributes.'),
-            exclude=('webui', 'cli'),
-            default=False,
-            autofill=True,
-        ),
     )
     has_output = (
         output.Output(
@@ -389,8 +238,9 @@ class permission_add(Method):
         output.Entry(
             'result',
         ),
-        output.PrimaryKey(
+        output.Output(
             'value',
+            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
@@ -424,20 +274,13 @@ class permission_add_member(Method):
             default=False,
             autofill=True,
         ),
-        parameters.Flag(
-            'no_members',
-            doc=_(u'Suppress processing of membership attributes.'),
-            exclude=('webui', 'cli'),
-            default=False,
-            autofill=True,
-        ),
         parameters.Str(
             'privilege',
             required=False,
             multivalue=True,
             cli_name='privileges',
             label=_(u'member privilege'),
-            doc=_(u'privileges to add'),
+            doc=_(u'comma-separated list of privileges to add'),
             alwaysask=True,
         ),
     )
@@ -460,7 +303,7 @@ class permission_add_member(Method):
 
 @register()
 class permission_add_noaci(Method):
-    __doc__ = _("Add a system permission without an ACI (internal command)")
+    __doc__ = _("Add a system permission without an ACI")
 
     NO_CLI = True
 
@@ -473,9 +316,10 @@ class permission_add_noaci(Method):
     )
     takes_options = (
         parameters.Str(
-            'ipapermissiontype',
-            multivalue=True,
-            label=_(u'Permission flags'),
+            'permissiontype',
+            required=False,
+            cli_metavar="['SYSTEM']",
+            label=_(u'Permission type'),
         ),
         parameters.Flag(
             'all',
@@ -491,13 +335,6 @@ class permission_add_noaci(Method):
             default=False,
             autofill=True,
         ),
-        parameters.Flag(
-            'no_members',
-            doc=_(u'Suppress processing of membership attributes.'),
-            exclude=('webui', 'cli'),
-            default=False,
-            autofill=True,
-        ),
     )
     has_output = (
         output.Output(
@@ -508,8 +345,9 @@ class permission_add_noaci(Method):
         output.Entry(
             'result',
         ),
-        output.PrimaryKey(
+        output.Output(
             'value',
+            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
@@ -554,8 +392,10 @@ class permission_del(Method):
             dict,
             doc=_(u'List of deletions that failed'),
         ),
-        output.ListOfPrimaryKeys(
+        output.Output(
             'value',
+            unicode,
+            doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
 
@@ -579,147 +419,62 @@ class permission_find(Method):
             label=_(u'Permission name'),
         ),
         parameters.Str(
-            'ipapermright',
+            'permissions',
             required=False,
             multivalue=True,
-            cli_name='right',
-            cli_metavar="['read', 'search', 'compare', 'write', 'add', 'delete', 'all']",
-            label=_(u'Granted rights'),
-            doc=_(u'Rights to grant (read, search, compare, write, add, delete, all)'),
+            label=_(u'Permissions'),
+            doc=_(u'Comma-separated list of permissions to grant (read, write, add, delete, all)'),
         ),
         parameters.Str(
             'attrs',
             required=False,
             multivalue=True,
-            label=_(u'Effective attributes'),
-            doc=_(u'All attributes to which the permission applies'),
+            label=_(u'Attributes'),
+            doc=_(u'Comma-separated list of attributes'),
+            no_convert=True,
         ),
         parameters.Str(
-            'ipapermincludedattr',
+            'type',
             required=False,
-            multivalue=True,
-            cli_name='includedattrs',
-            label=_(u'Included attributes'),
-            doc=_(u'User-specified attributes to which the permission applies'),
-        ),
-        parameters.Str(
-            'ipapermexcludedattr',
-            required=False,
-            multivalue=True,
-            cli_name='excludedattrs',
-            label=_(u'Excluded attributes'),
-            doc=_(u'User-specified attributes to which the permission explicitly does not apply'),
-        ),
-        parameters.Str(
-            'ipapermdefaultattr',
-            required=False,
-            multivalue=True,
-            cli_name='defaultattrs',
-            label=_(u'Default attributes'),
-            doc=_(u'Attributes to which the permission applies by default'),
-        ),
-        parameters.Str(
-            'ipapermbindruletype',
-            required=False,
-            cli_name='bindtype',
-            cli_metavar="['permission', 'all', 'anonymous']",
-            label=_(u'Bind rule type'),
-            default=u'permission',
-        ),
-        parameters.Str(
-            'ipapermlocation',
-            required=False,
-            cli_name='subtree',
-            label=_(u'Subtree'),
-            doc=_(u'Subtree to apply permissions to'),
-        ),
-        parameters.Str(
-            'extratargetfilter',
-            required=False,
-            multivalue=True,
-            cli_name='filter',
-            label=_(u'Extra target filter'),
-        ),
-        parameters.Str(
-            'ipapermtargetfilter',
-            required=False,
-            multivalue=True,
-            cli_name='rawfilter',
-            label=_(u'Raw target filter'),
-            doc=_(u'All target filters, including those implied by type and memberof'),
-        ),
-        parameters.DNParam(
-            'ipapermtarget',
-            required=False,
-            cli_name='target',
-            label=_(u'Target DN'),
-            doc=_(u'Optional DN to apply the permission to (must be in the subtree, but may not yet exist)'),
-        ),
-        parameters.DNParam(
-            'ipapermtargetto',
-            required=False,
-            cli_name='targetto',
-            label=_(u'Target DN subtree'),
-            doc=_(u'Optional DN subtree where an entry can be moved to (must be in the subtree, but may not yet exist)'),
-        ),
-        parameters.DNParam(
-            'ipapermtargetfrom',
-            required=False,
-            cli_name='targetfrom',
-            label=_(u'Origin DN subtree'),
-            doc=_(u'Optional DN subtree from where an entry can be moved (must be in the subtree, but may not yet exist)'),
+            cli_metavar="['user', 'group', 'host', 'service', 'hostgroup', 'netgroup', 'dnsrecord']",
+            label=_(u'Type'),
+            doc=_(u'Type of IPA object (user, group, host, hostgroup, service, netgroup, dns)'),
         ),
         parameters.Str(
             'memberof',
             required=False,
-            multivalue=True,
             label=_(u'Member of group'),
-            doc=_(u'Target members of a group (sets memberOf targetfilter)'),
+            doc=_(u'Target members of a group'),
+        ),
+        parameters.Str(
+            'filter',
+            required=False,
+            label=_(u'Filter'),
+            doc=_(u'Legal LDAP filter (e.g. ou=Engineering)'),
+        ),
+        parameters.Str(
+            'subtree',
+            required=False,
+            label=_(u'Subtree'),
+            doc=_(u'Subtree to apply permissions to'),
         ),
         parameters.Str(
             'targetgroup',
             required=False,
             label=_(u'Target group'),
-            doc=_(u'User group to apply permissions to (sets target)'),
-        ),
-        parameters.Str(
-            'type',
-            required=False,
-            label=_(u'Type'),
-            doc=_(u'Type of IPA object (sets subtree and objectClass targetfilter)'),
-        ),
-        parameters.Str(
-            'filter',
-            required=False,
-            multivalue=True,
-            doc=_(u'Deprecated; use extratargetfilter'),
-            exclude=('cli', 'webui'),
-        ),
-        parameters.Str(
-            'subtree',
-            required=False,
-            multivalue=True,
-            doc=_(u'Deprecated; use ipapermlocation'),
-            exclude=('cli', 'webui'),
-        ),
-        parameters.Str(
-            'permissions',
-            required=False,
-            multivalue=True,
-            doc=_(u'Deprecated; use ipapermright'),
-            exclude=('cli', 'webui'),
+            doc=_(u'User group to apply permissions to'),
         ),
         parameters.Int(
             'timelimit',
             required=False,
             label=_(u'Time Limit'),
-            doc=_(u'Time limit of search in seconds (0 is unlimited)'),
+            doc=_(u'Time limit of search in seconds'),
         ),
         parameters.Int(
             'sizelimit',
             required=False,
             label=_(u'Size Limit'),
-            doc=_(u'Maximum number of entries returned (0 is unlimited)'),
+            doc=_(u'Maximum number of entries returned'),
         ),
         parameters.Flag(
             'all',
@@ -735,13 +490,6 @@ class permission_find(Method):
             default=False,
             autofill=True,
         ),
-        parameters.Flag(
-            'no_members',
-            doc=_(u'Suppress processing of membership attributes.'),
-            exclude=('webui', 'cli'),
-            default=False,
-            autofill=True,
-        ),
         parameters.Flag(
             'pkey_only',
             required=False,
@@ -786,127 +534,50 @@ class permission_mod(Method):
     )
     takes_options = (
         parameters.Str(
-            'ipapermright',
+            'permissions',
             required=False,
             multivalue=True,
-            cli_name='right',
-            cli_metavar="['read', 'search', 'compare', 'write', 'add', 'delete', 'all']",
-            label=_(u'Granted rights'),
-            doc=_(u'Rights to grant (read, search, compare, write, add, delete, all)'),
+            label=_(u'Permissions'),
+            doc=_(u'Comma-separated list of permissions to grant (read, write, add, delete, all)'),
         ),
         parameters.Str(
             'attrs',
             required=False,
             multivalue=True,
-            label=_(u'Effective attributes'),
-            doc=_(u'All attributes to which the permission applies'),
+            label=_(u'Attributes'),
+            doc=_(u'Comma-separated list of attributes'),
+            no_convert=True,
         ),
         parameters.Str(
-            'ipapermincludedattr',
+            'type',
             required=False,
-            multivalue=True,
-            cli_name='includedattrs',
-            label=_(u'Included attributes'),
-            doc=_(u'User-specified attributes to which the permission applies'),
-        ),
-        parameters.Str(
-            'ipapermexcludedattr',
-            required=False,
-            multivalue=True,
-            cli_name='excludedattrs',
-            label=_(u'Excluded attributes'),
-            doc=_(u'User-specified attributes to which the permission explicitly does not apply'),
-        ),
-        parameters.Str(
-            'ipapermbindruletype',
-            required=False,
-            cli_name='bindtype',
-            cli_metavar="['permission', 'all', 'anonymous']",
-            label=_(u'Bind rule type'),
-            default=u'permission',
-        ),
-        parameters.Str(
-            'ipapermlocation',
-            required=False,
-            cli_name='subtree',
-            label=_(u'Subtree'),
-            doc=_(u'Subtree to apply permissions to'),
-        ),
-        parameters.Str(
-            'extratargetfilter',
-            required=False,
-            multivalue=True,
-            cli_name='filter',
-            label=_(u'Extra target filter'),
-        ),
-        parameters.Str(
-            'ipapermtargetfilter',
-            required=False,
-            multivalue=True,
-            cli_name='rawfilter',
-            label=_(u'Raw target filter'),
-            doc=_(u'All target filters, including those implied by type and memberof'),
-        ),
-        parameters.DNParam(
-            'ipapermtarget',
-            required=False,
-            cli_name='target',
-            label=_(u'Target DN'),
-            doc=_(u'Optional DN to apply the permission to (must be in the subtree, but may not yet exist)'),
-        ),
-        parameters.DNParam(
-            'ipapermtargetto',
-            required=False,
-            cli_name='targetto',
-            label=_(u'Target DN subtree'),
-            doc=_(u'Optional DN subtree where an entry can be moved to (must be in the subtree, but may not yet exist)'),
-        ),
-        parameters.DNParam(
-            'ipapermtargetfrom',
-            required=False,
-            cli_name='targetfrom',
-            label=_(u'Origin DN subtree'),
-            doc=_(u'Optional DN subtree from where an entry can be moved (must be in the subtree, but may not yet exist)'),
+            cli_metavar="['user', 'group', 'host', 'service', 'hostgroup', 'netgroup', 'dnsrecord']",
+            label=_(u'Type'),
+            doc=_(u'Type of IPA object (user, group, host, hostgroup, service, netgroup, dns)'),
         ),
         parameters.Str(
             'memberof',
             required=False,
-            multivalue=True,
             label=_(u'Member of group'),
-            doc=_(u'Target members of a group (sets memberOf targetfilter)'),
+            doc=_(u'Target members of a group'),
+        ),
+        parameters.Str(
+            'filter',
+            required=False,
+            label=_(u'Filter'),
+            doc=_(u'Legal LDAP filter (e.g. ou=Engineering)'),
+        ),
+        parameters.Str(
+            'subtree',
+            required=False,
+            label=_(u'Subtree'),
+            doc=_(u'Subtree to apply permissions to'),
         ),
         parameters.Str(
             'targetgroup',
             required=False,
             label=_(u'Target group'),
-            doc=_(u'User group to apply permissions to (sets target)'),
-        ),
-        parameters.Str(
-            'type',
-            required=False,
-            label=_(u'Type'),
-            doc=_(u'Type of IPA object (sets subtree and objectClass targetfilter)'),
-        ),
-        parameters.Str(
-            'filter',
-            required=False,
-            multivalue=True,
-            doc=_(u'Deprecated; use extratargetfilter'),
-            exclude=('cli', 'webui'),
-        ),
-        parameters.Str(
-            'subtree',
-            required=False,
-            multivalue=True,
-            doc=_(u'Deprecated; use ipapermlocation'),
-            exclude=('cli', 'webui'),
-        ),
-        parameters.Str(
-            'permissions',
-            required=False,
-            multivalue=True,
-            doc=_(u'Deprecated; use ipapermright'),
-            exclude=('cli', 'webui'),
+            doc=_(u'User group to apply permissions to'),
         ),
         parameters.Str(
             'setattr',
@@ -950,13 +621,6 @@ class permission_mod(Method):
             default=False,
             autofill=True,
         ),
-        parameters.Flag(
-            'no_members',
-            doc=_(u'Suppress processing of membership attributes.'),
-            exclude=('webui', 'cli'),
-            default=False,
-            autofill=True,
-        ),
         parameters.Str(
             'rename',
             required=False,
@@ -973,8 +637,9 @@ class permission_mod(Method):
         output.Entry(
             'result',
         ),
-        output.PrimaryKey(
+        output.Output(
             'value',
+            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
@@ -1008,20 +673,13 @@ class permission_remove_member(Method):
             default=False,
             autofill=True,
         ),
-        parameters.Flag(
-            'no_members',
-            doc=_(u'Suppress processing of membership attributes.'),
-            exclude=('webui', 'cli'),
-            default=False,
-            autofill=True,
-        ),
         parameters.Str(
             'privilege',
             required=False,
             multivalue=True,
             cli_name='privileges',
             label=_(u'member privilege'),
-            doc=_(u'privileges to remove'),
+            doc=_(u'comma-separated list of privileges to remove'),
             alwaysask=True,
         ),
     )
@@ -1075,13 +733,6 @@ class permission_show(Method):
             default=False,
             autofill=True,
         ),
-        parameters.Flag(
-            'no_members',
-            doc=_(u'Suppress processing of membership attributes.'),
-            exclude=('webui', 'cli'),
-            default=False,
-            autofill=True,
-        ),
     )
     has_output = (
         output.Output(
@@ -1092,8 +743,9 @@ class permission_show(Method):
         output.Entry(
             'result',
         ),
-        output.PrimaryKey(
+        output.Output(
             'value',
+            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
