@@ -50,7 +50,6 @@ class privilege(Object):
         ),
         parameters.Str(
             'description',
-            required=False,
             label=_(u'Description'),
             doc=_(u'Privilege description'),
         ),
@@ -81,7 +80,6 @@ class privilege_add(Method):
     takes_options = (
         parameters.Str(
             'description',
-            required=False,
             cli_name='desc',
             label=_(u'Description'),
             doc=_(u'Privilege description'),
@@ -114,13 +112,6 @@ class privilege_add(Method):
             default=False,
             autofill=True,
         ),
-        parameters.Flag(
-            'no_members',
-            doc=_(u'Suppress processing of membership attributes.'),
-            exclude=('webui', 'cli'),
-            default=False,
-            autofill=True,
-        ),
     )
     has_output = (
         output.Output(
@@ -131,8 +122,9 @@ class privilege_add(Method):
         output.Entry(
             'result',
         ),
-        output.PrimaryKey(
+        output.Output(
             'value',
+            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
@@ -166,20 +158,13 @@ class privilege_add_member(Method):
             default=False,
             autofill=True,
         ),
-        parameters.Flag(
-            'no_members',
-            doc=_(u'Suppress processing of membership attributes.'),
-            exclude=('webui', 'cli'),
-            default=False,
-            autofill=True,
-        ),
         parameters.Str(
             'role',
             required=False,
             multivalue=True,
             cli_name='roles',
             label=_(u'member role'),
-            doc=_(u'roles to add'),
+            doc=_(u'comma-separated list of roles to add'),
             alwaysask=True,
         ),
     )
@@ -226,20 +211,13 @@ class privilege_add_permission(Method):
             default=False,
             autofill=True,
         ),
-        parameters.Flag(
-            'no_members',
-            doc=_(u'Suppress processing of membership attributes.'),
-            exclude=('webui', 'cli'),
-            default=False,
-            autofill=True,
-        ),
         parameters.Str(
             'permission',
             required=False,
             multivalue=True,
             cli_name='permissions',
             label=_(u'permission'),
-            doc=_(u'permissions'),
+            doc=_(u'comma-separated list of permissions'),
             alwaysask=True,
         ),
     )
@@ -291,8 +269,10 @@ class privilege_del(Method):
             dict,
             doc=_(u'List of deletions that failed'),
         ),
-        output.ListOfPrimaryKeys(
+        output.Output(
             'value',
+            unicode,
+            doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
 
@@ -326,13 +306,13 @@ class privilege_find(Method):
             'timelimit',
             required=False,
             label=_(u'Time Limit'),
-            doc=_(u'Time limit of search in seconds (0 is unlimited)'),
+            doc=_(u'Time limit of search in seconds'),
         ),
         parameters.Int(
             'sizelimit',
             required=False,
             label=_(u'Size Limit'),
-            doc=_(u'Maximum number of entries returned (0 is unlimited)'),
+            doc=_(u'Maximum number of entries returned'),
         ),
         parameters.Flag(
             'all',
@@ -348,13 +328,6 @@ class privilege_find(Method):
             default=False,
             autofill=True,
         ),
-        parameters.Flag(
-            'no_members',
-            doc=_(u'Suppress processing of membership attributes.'),
-            exclude=('webui', 'cli'),
-            default=False,
-            autofill=True,
-        ),
         parameters.Flag(
             'pkey_only',
             required=False,
@@ -447,13 +420,6 @@ class privilege_mod(Method):
             default=False,
             autofill=True,
         ),
-        parameters.Flag(
-            'no_members',
-            doc=_(u'Suppress processing of membership attributes.'),
-            exclude=('webui', 'cli'),
-            default=False,
-            autofill=True,
-        ),
         parameters.Str(
             'rename',
             required=False,
@@ -470,8 +436,9 @@ class privilege_mod(Method):
         output.Entry(
             'result',
         ),
-        output.PrimaryKey(
+        output.Output(
             'value',
+            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
@@ -505,20 +472,13 @@ class privilege_remove_member(Method):
             default=False,
             autofill=True,
         ),
-        parameters.Flag(
-            'no_members',
-            doc=_(u'Suppress processing of membership attributes.'),
-            exclude=('webui', 'cli'),
-            default=False,
-            autofill=True,
-        ),
         parameters.Str(
             'role',
             required=False,
             multivalue=True,
             cli_name='roles',
             label=_(u'member role'),
-            doc=_(u'roles to remove'),
+            doc=_(u'comma-separated list of roles to remove'),
             alwaysask=True,
         ),
     )
@@ -565,20 +525,13 @@ class privilege_remove_permission(Method):
             default=False,
             autofill=True,
         ),
-        parameters.Flag(
-            'no_members',
-            doc=_(u'Suppress processing of membership attributes.'),
-            exclude=('webui', 'cli'),
-            default=False,
-            autofill=True,
-        ),
         parameters.Str(
             'permission',
             required=False,
             multivalue=True,
             cli_name='permissions',
             label=_(u'permission'),
-            doc=_(u'permissions'),
+            doc=_(u'comma-separated list of permissions'),
             alwaysask=True,
         ),
     )
@@ -632,13 +585,6 @@ class privilege_show(Method):
             default=False,
             autofill=True,
         ),
-        parameters.Flag(
-            'no_members',
-            doc=_(u'Suppress processing of membership attributes.'),
-            exclude=('webui', 'cli'),
-            default=False,
-            autofill=True,
-        ),
     )
     has_output = (
         output.Output(
@@ -649,8 +595,9 @@ class privilege_show(Method):
         output.Entry(
             'result',
         ),
-        output.PrimaryKey(
+        output.Output(
             'value',
+            unicode,
             doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
         ),
     )
