@@ -2,6 +2,7 @@
 # Copyright (C) 2016  FreeIPA Contributors see COPYING for license
 #
 
+from collections.abc import Mapping, Sequence
 import errno
 import json
 import logging
@@ -17,7 +18,6 @@ import six
 
 from ipaclient.frontend import ClientCommand, ClientMethod
 from ipalib import errors, parameters, plugable
-from ipalib.constants import USER_CACHE_PATH
 from ipalib.errors import SchemaUpToDate
 from ipalib.frontend import Object
 from ipalib.output import Output
@@ -27,13 +27,6 @@ from ipapython.ipautil import fsdecode
 from ipapython.dn import DN
 from ipapython.dnsutil import DNSName
 
-# pylint: disable=no-name-in-module, import-error
-if six.PY3:
-    from collections.abc import Mapping, Sequence
-else:
-    from collections import Mapping, Sequence
-# pylint: enable=no-name-in-module, import-error
-
 logger = logging.getLogger(__name__)
 
 FORMAT = '1'
@@ -95,7 +88,7 @@ class _SchemaObject(Object):
     pass
 
 
-class _SchemaPlugin(object):
+class _SchemaPlugin:
     bases = None
     schema_key = None
 
@@ -352,7 +345,7 @@ class NotAvailable(Exception):
     pass
 
 
-class Schema(object):
+class Schema:
     """
     Store and provide schema for commands and topics
 
@@ -373,9 +366,9 @@ class Schema(object):
 
     """
     namespaces = {'classes', 'commands', 'topics'}
-    _DIR = os.path.join(USER_CACHE_PATH, 'ipa', 'schema', FORMAT)
 
-    def __init__(self, client, fingerprint=None):
+    def __init__(self, client, fingerprint=None, ttl=0):
+        self._dir = os.path.join(client.api.env.cache_dir, 'schema', FORMAT)
         self._dict = {}
         self._namespaces = {}
         self._help = None
@@ -384,7 +377,6 @@ class Schema(object):
             self._dict[ns] = {}
             self._namespaces[ns] = _SchemaNameSpace(self, ns)
 
-        ttl = None
         read_failed = False
 
         if fingerprint is not None:
@@ -416,7 +408,7 @@ class Schema(object):
         fps = []
         if not ignore_cache:
             try:
-                fps = [fsdecode(f) for f in os.listdir(self._DIR)]
+                fps = [fsdecode(f) for f in os.listdir(self._dir)]
             except EnvironmentError:
                 pass
 
@@ -446,7 +438,7 @@ class Schema(object):
     def _read_schema(self, fingerprint):
         # It's more efficient to read zip file members at once than to open
         # the zip file a couple of times, see #6690.
-        filename = os.path.join(self._DIR, fingerprint)
+        filename = os.path.join(self._dir, fingerprint)
         with zipfile.ZipFile(filename, 'r') as schema:
             for name in schema.namelist():
                 ns, _slash, key = name.partition('/')
@@ -484,13 +476,13 @@ class Schema(object):
 
     def _write_schema(self, fingerprint):
         try:
-            os.makedirs(self._DIR)
+            os.makedirs(self._dir)
         except EnvironmentError as e:
             if e.errno != errno.EEXIST:
                 raise
 
         with tempfile.NamedTemporaryFile('wb', prefix=fingerprint,
-                                         dir=self._DIR, delete=False) as f:
+                                         dir=self._dir, delete=False) as f:
             try:
                 self._write_schema_data(f)
                 ipautil.flush_sync(f)
@@ -499,7 +491,7 @@ class Schema(object):
                 os.unlink(f.name)
                 raise
             else:
-                os.rename(f.name, os.path.join(self._DIR, fingerprint))
+                os.rename(f.name, os.path.join(self._dir, fingerprint))
 
     def _write_schema_data(self, fileobj):
         with zipfile.ZipFile(fileobj, 'w', zipfile.ZIP_DEFLATED) as schema:
@@ -533,7 +525,7 @@ class Schema(object):
     def get_help(self, namespace, member):
         if isinstance(self._help, bytes):
             self._help = json.loads(
-                self._help.decode('utf-8')  # pylint: disable=no-member
+                self._help.decode('utf-8')
             )
 
         return self._help[namespace][member]
@@ -554,10 +546,10 @@ def get_package(server_info, client):
                 else:
                     schema = Schema(client, fingerprint)
             except SchemaUpToDate as e:
-                schema = Schema(client, e.fingerprint)
+                schema = Schema(client, e.fingerprint, e.ttl)
         except NotAvailable:
             fingerprint = None
-            ttl = None
+            ttl = 3600  # set a ttl so we don't hammer the remote server
         except SchemaUpToDate as e:
             fingerprint = e.fingerprint
             ttl = e.ttl
