@@ -45,6 +45,7 @@ from ipalib.constants import (
     CONFIG_SECTION,
     OVERRIDE_ERROR, SET_ERROR, DEL_ERROR,
     TLS_VERSIONS, TLS_VERSION_DEFAULT_MIN, TLS_VERSION_DEFAULT_MAX,
+    USER_CACHE_PATH
 )
 from ipalib import errors
 
@@ -270,9 +271,9 @@ class Env:
         if type(value) not in (unicode, int, float, bool, type(None), DN):
             raise TypeError(key, value)
         object.__setattr__(self, key, value)
-        # pylint: disable=unsupported-assignment-operation, no-member
+        # pylint: disable=no-member
         self.__d[key] = value
-        # pylint: enable=unsupported-assignment-operation, no-member
+        # pylint: enable=no-member
 
     def __getitem__(self, key):
         """
@@ -507,6 +508,11 @@ class Env:
         if 'nss_dir' not in self:
             self.nss_dir = self._join('confdir', 'nssdb')
 
+        # user cache dir for IPA, defaults to '$XDG_CACHE_HOME/ipa' or
+        # '~/.cache/ipa'. XDG_CACHE_HOME env var is cached at import time.
+        if 'cache_dir' not in self:
+            self.cache_dir = os.path.join(USER_CACHE_PATH, 'ipa')
+
         if 'tls_ca_cert' not in self:
             self.tls_ca_cert = self._join('confdir', 'ca.crt')
 
@@ -600,12 +606,10 @@ class Env:
         # and server from jsonrpc_uri so that when only server or xmlrpc_uri
         # is specified, all 3 keys have a value.)
         if 'xmlrpc_uri' not in self and 'server' in self:
-            # pylint: disable=no-member, access-member-before-definition
             self.xmlrpc_uri = 'https://{}/ipa/xml'.format(self.server)
 
         # Derive ldap_uri from server
         if 'ldap_uri' not in self and 'server' in self:
-            # pylint: disable=no-member, access-member-before-definition
             self.ldap_uri = 'ldap://{}'.format(self.server)
 
         # Derive jsonrpc_uri from xmlrpc_uri
