@@ -24,6 +24,15 @@ All constants centralised in one file.
 
 import os
 import string
+import uuid
+import warnings
+
+warnings.filterwarnings(
+    "ignore",
+    "TripleDES has been moved to "
+    "cryptography.hazmat.decrepit.ciphers.algorithms.TripleDES and "
+    "will be removed from this module in 48.0.0",
+    category=UserWarning)
 
 from ipaplatform.constants import constants as _constants
 from ipapython.dn import DN
@@ -55,6 +64,8 @@ TLS_VERSION_MAXIMAL = "tls1.3"
 TLS_VERSION_DEFAULT_MIN = None
 TLS_VERSION_DEFAULT_MAX = None
 
+SD_IPA_API_MESSAGE_ID = uuid.uuid3(uuid.NAMESPACE_DNS, 'IPA.API')
+
 # regular expression NameSpace member names must match:
 NAME_REGEX = r'^[a-z][_a-z0-9]*[a-z0-9]$|^[a-z]$'
 
@@ -273,6 +284,7 @@ DEFAULT_CONFIG = (
     ('conf_default', object),  # File containing context independent config
     ('plugins_on_demand', object),  # Whether to finalize plugins on-demand (bool)
     ('nss_dir', object),  # Path to nssdb, default {confdir}/nssdb
+    ('cache_dir', object),  # ~/.cache/ipa directory, may use XDG_CACHE_HOME env
     ('tls_ca_cert', object),  # Path to CA cert file
 
     # Set in Env._finalize_core():
@@ -377,6 +389,7 @@ VAULT_WRAPPING_SUPPORTED_ALGOS = (
 VAULT_WRAPPING_DEFAULT_ALGO = VAULT_WRAPPING_AES128_CBC
 
 # Add 3DES for backwards compatibility if supported
-if backend.cipher_supported(algorithms.TripleDES(b"\x00" * 8),
-                            modes.CBC(b"\x00" * 8)):
-    VAULT_WRAPPING_SUPPORTED_ALGOS += (VAULT_WRAPPING_3DES,)
+if getattr(algorithms, 'TripleDES', None):
+    if backend.cipher_supported(algorithms.TripleDES(
+                                b"\x00" * 8), modes.CBC(b"\x00" * 8)):
+        VAULT_WRAPPING_SUPPORTED_ALGOS += (VAULT_WRAPPING_3DES,)
