@@ -42,8 +42,9 @@ if __name__ == '__main__':
             "pyasn1",
             "pyasn1-modules",
             "six",
+            "urllib3",
         ],
         extras_require={
-            "install": ["ipaplatform"],
+            "install": ["dbus-python"],  # for certmonger and resolve1
         },
     )
