@@ -21,11 +21,9 @@ import re
 import datetime
 import email.utils
 from calendar import timegm
+from urllib.parse import urlparse
+from ipapython.ipautil import datetime_from_utctimestamp
 
-import six
-from six.moves.urllib.parse import urlparse
-
-from ipapython.ipa_log_manager import log_mgr
 
 '''
 Core Python has two cookie libraries, Cookie.py targeted to server
@@ -66,7 +64,8 @@ escaping and unescapin.
 
 #-------------------------------------------------------------------------------
 
-class Cookie(object):
+
+class Cookie:
     '''
     A Cookie object has the following attributes:
 
@@ -110,7 +109,7 @@ class Cookie(object):
 
     cookie = Cookie('session', session_id,
                     domain=my_domain, path=mypath,
-                    httpOnly=True, secure=True, expires=expiration)
+                    httponly=True, secure=True, expires=expiration)
     headers.append(('Set-Cookie', str(cookie)))
 
 
@@ -186,7 +185,7 @@ class Cookie(object):
         # use the RFC 1123 parsing function which uses only English
 
         try:
-            dt = datetime.datetime(*email.utils.parsedate(s)[0:6])
+            dt = email.utils.parsedate_to_datetime(s)
         except Exception as e:
             raise ValueError("unable to parse expires datetime '%s': %s" % (s, e))
 
@@ -221,7 +220,7 @@ class Cookie(object):
             return '/'
 
         if url_path.count('/') <= 1:
-            return'/'
+            return '/'
 
         return url_path[:url_path.rindex('/')]
 
@@ -352,9 +351,6 @@ class Cookie(object):
 
     def __init__(self, key, value, domain=None, path=None, max_age=None, expires=None,
                  secure=None, httponly=None, timestamp=None):
-
-        log_mgr.get_logger(self, True)
-
         self.key = key
         self.value = value
         self.domain = domain
@@ -394,9 +390,9 @@ class Cookie(object):
             self._timestamp = None
         elif isinstance(value, datetime.datetime):
             self._timestamp = value
-        elif isinstance(value, (six.integer_types, float)):
-            self._timestamp = datetime.datetime.utcfromtimestamp(value)
-        elif isinstance(value, six.string_types):
+        elif isinstance(value, (int, float)):
+            self._timestamp = datetime_from_utctimestamp(value, units=1)
+        elif isinstance(value, str):
             self._timestamp = Cookie.parse_datetime(value)
         else:
             raise TypeError('value must be datetime, int, long, float, basestring or None, not %s' % \
@@ -420,9 +416,11 @@ class Cookie(object):
             self._expires = None
         elif isinstance(value, datetime.datetime):
             self._expires = value
-        elif isinstance(value, (six.integer_types, float)):
-            self._expires = datetime.datetime.utcfromtimestamp(value)
-        elif isinstance(value, six.string_types):
+            if self._expires.tzinfo is None:
+                self._expires.replace(tzinfo=datetime.timezone.utc)
+        elif isinstance(value, (int, float)):
+            self._expires = datetime_from_utctimestamp(value, units=1)
+        elif isinstance(value, str):
             self._expires = Cookie.parse_datetime(value)
         else:
             raise TypeError('value must be datetime, int, long, float, basestring or None, not %s' % \
@@ -446,7 +444,7 @@ class Cookie(object):
             except Exception:
                 raise ValueError("Max-Age value '%s' not convertable to integer" % value)
 
-    def __set_attr(self, name, value):
+    def __set_attr(self, name, value):  # pylint: disable=unused-private-member
         '''
         Sets one of the predefined cookie attributes.
         '''
@@ -543,7 +541,7 @@ class Cookie(object):
         received from.
         '''
 
-        scheme, domain, path, params, query, fragment = urlparse(url)
+        _scheme, domain, path, _params, _query, _fragment = urlparse(url)
 
         if self.domain is None:
             self.domain = domain.lower()
@@ -597,10 +595,12 @@ class Cookie(object):
             # FIXME: At the moment we can't import from ipalib at the
             # module level because of a dependency loop (cycle) in the
             # import. Our module layout needs to be refactored.
+            # pylint: disable=ipa-forbidden-import
             from ipalib.util import validate_domain_name
+            # pylint: enable=ipa-forbidden-import
             try:
                 validate_domain_name(url_domain)
-            except Exception as e:
+            except Exception:
                 return False
 
             if cookie_domain is None:
@@ -645,11 +645,14 @@ class Cookie(object):
 
         cookie_name = self.key
 
-        url_scheme, url_domain, url_path, url_params, url_query, url_fragment = urlparse(url)
+        (
+            url_scheme, url_domain, url_path,
+            _url_params, _url_query, _url_fragment
+        ) = urlparse(url)
 
         cookie_expiration = self.get_expiration()
         if cookie_expiration is not None:
-            now = datetime.datetime.utcnow()
+            now = datetime.datetime.now(tz=datetime.timezone.utc)
             if cookie_expiration < now:
                 raise Cookie.Expired("cookie named '%s'; expired at %s'" % \
                                      (cookie_name,
