@@ -48,9 +48,9 @@ import six
 from six.moves import input
 
 try:
-    import netifaces
+    import ifaddr
 except ImportError:
-    netifaces = None
+    ifaddr = None
 
 from ipapython.dn import DN
 from ipaplatform.paths import paths
@@ -203,42 +203,37 @@ class CheckedIPAddress(UnsafeIPAddress):
         :return: InterfaceDetails named tuple or None if no interface has
         this address
         """
-        if netifaces is None:
-            raise ImportError("netifaces")
+        if ifaddr is None:
+            raise ImportError("ifaddr")
         logger.debug("Searching for an interface of IP address: %s", self)
+
         if self.version == 4:
-            family = netifaces.AF_INET
+            family_ips = (
+                (ip.ip, ip.network_prefix, ip.nice_name)
+                for ips in [a.ips for a in ifaddr.get_adapters()]
+                for ip in ips if not isinstance(ip.ip, tuple)
+            )
         elif self.version == 6:
-            family = netifaces.AF_INET6
+            family_ips = (
+                (ip.ip[0], ip.network_prefix, ip.nice_name)
+                for ips in [a.ips for a in ifaddr.get_adapters()]
+                for ip in ips if isinstance(ip.ip, tuple)
+            )
         else:
             raise ValueError(
                 "Unsupported address family ({})".format(self.version)
             )
 
-        for interface in netifaces.interfaces():
-            for ifdata in netifaces.ifaddresses(interface).get(family, []):
+        for ip, prefix, ifname in family_ips:
+            ifaddrmask = "{ip}/{prefix}".format(ip=ip, prefix=prefix)
+            logger.debug(
+                "Testing local IP address: %s (interface: %s)",
+                ifaddrmask, ifname)
+            ifnet = netaddr.IPNetwork(ifaddrmask)
 
-                # link-local addresses contain '%suffix' that causes parse
-                # errors in IPNetwork
-                ifaddr = ifdata['addr'].split(u'%', 1)[0]
+            if ifnet.ip == self:
+                return InterfaceDetails(ifname, ifnet)
 
-                # newer versions of netifaces provide IPv6 netmask in format
-                # 'ffff:ffff:ffff:ffff::/64'. We have to split and use prefix
-                # or the netmask with older versions
-                ifmask = ifdata['netmask'].split(u'/')[-1]
-
-                ifaddrmask = '{addr}/{netmask}'.format(
-                    addr=ifaddr,
-                    netmask=ifmask
-                )
-                logger.debug(
-                    "Testing local IP address: %s (interface: %s)",
-                    ifaddrmask, interface)
-
-                ifnet = netaddr.IPNetwork(ifaddrmask)
-
-                if ifnet.ip == self:
-                    return InterfaceDetails(interface, ifnet)
         return None
 
     def set_ip_net(self, ifnet):
@@ -1663,9 +1658,16 @@ def remove_ccache(ccache_path=None, run_as=None):
             "Failed to clear Kerberos credentials cache: %s", e)
 
 
-def remove_file(filename):
+def remove_file(filename, only_if_empty=False):
     """Remove a file and log any exceptions raised.
+
+       :only_if_empty: only remove the file if empty. Default False.
     """
+    if only_if_empty and os.path.exists(filename):
+        file_stat = os.stat(filename)
+        if file_stat.st_size > 0:
+            logger.debug('%s is not empty.', filename)
+            return
     try:
         os.unlink(filename)
     except Exception as e:
@@ -1674,6 +1676,15 @@ def remove_file(filename):
             logger.error('Error removing %s: %s', filename, str(e))
 
 
+def remove_directory(dir):
+    """Remove an empty directory."""
+    try:
+        os.rmdir(dir)
+    except OSError as e:
+        if e.errno not in {errno.ENOENT, errno.ENOTEMPTY}:
+            logger.error("Failed to remove directory %s", dir)
+
+
 def rmtree(path):
     """
     Remove a directory structure and log any exceptions raised.
