@@ -28,6 +28,7 @@ import time
 import datetime
 import sys
 import os
+import json
 from random import randint
 
 import ldap
@@ -63,9 +64,10 @@ WINSYNC = 2
 
 # List of attributes that need to be excluded from replication initialization.
 TOTAL_EXCLUDES = ('entryusn',
-                 'krblastsuccessfulauth',
-                 'krblastfailedauth',
-                 'krbloginfailedcount')
+                  'krblastsuccessfulauth',
+                  'krblastfailedauth',
+                  'krbloginfailedcount',
+                  'passwordgraceusertime',)
 
 # List of attributes that need to be excluded from normal replication.
 EXCLUDES = ('memberof', 'idnssoaserial') + TOTAL_EXCLUDES
@@ -736,8 +738,15 @@ class ReplicationManager:
         mtent = self.get_mapping_tree_entry()
         dn = mtent.dn
 
+        def get_entry(dn, attrs):
+            return self.conn.get_entry(DN(dn), attrs)
+
+        replication_plugin_name = (
+            installutils.get_replication_plugin_name(get_entry)
+        )
+
         plgent = self.conn.get_entry(
-            DN(('cn', 'Multimaster Replication Plugin'), ('cn', 'plugins'),
+            DN(('cn', replication_plugin_name), ('cn', 'plugins'),
                ('cn', 'config')),
             ['nsslapd-pluginPath'])
         path = plgent.single_value.get('nsslapd-pluginPath')
@@ -1058,6 +1067,7 @@ class ReplicationManager:
         attrlist = ['cn', 'nsds5BeginReplicaRefresh',
                     'nsds5replicaUpdateInProgress',
                     'nsds5ReplicaLastInitStatus',
+                    'nsds5ReplicaLastInitStatusJSON',
                     'nsds5ReplicaLastInitStart',
                     'nsds5ReplicaLastInitEnd']
         entry = conn.get_entry(agmtdn, attrlist)
@@ -1068,7 +1078,14 @@ class ReplicationManager:
             refresh = entry.single_value.get('nsds5BeginReplicaRefresh')
             inprogress = entry.single_value.get('nsds5replicaUpdateInProgress')
             status = entry.single_value.get('nsds5ReplicaLastInitStatus')
-            if not refresh: # done - check status
+            json_status = \
+                entry.single_value.get('nsds5ReplicaLastInitStatusJSON')
+            if not refresh:  # done - check status
+                if json_status:
+                    # Just reset status with the JSON 'message'
+                    status_obj = json.loads(json_status)
+                    status = status_obj['message']
+
                 if not status:
                     print("No status yet")
                 elif status.find("replica busy") > -1:
@@ -1079,7 +1096,7 @@ class ReplicationManager:
                 elif status.find("Total update succeeded") > -1:
                     print("\nUpdate succeeded")
                     done = True
-                elif inprogress.lower() == 'true':
+                elif inprogress:
                     print("\nUpdate in progress yet not in progress")
                 else:
                     print("\n[%s] reports: Update failed! Status: [%s]"
@@ -1099,8 +1116,11 @@ class ReplicationManager:
         done = False
         hasError = 0
         error_message = ''
-        attrlist = ['cn', 'nsds5replicaUpdateInProgress',
-                    'nsds5ReplicaLastUpdateStatus', 'nsds5ReplicaLastUpdateStart',
+        attrlist = ['cn',
+                    'nsds5replicaUpdateInProgress',
+                    'nsds5ReplicaLastUpdateStatus',
+                    'nsds5ReplicaLastUpdateStatusjson',
+                    'nsds5ReplicaLastUpdateStart',
                     'nsds5ReplicaLastUpdateEnd']
         entry = conn.get_entry(agmtdn, attrlist)
         if not entry:
@@ -1109,6 +1129,8 @@ class ReplicationManager:
         else:
             inprogress = entry.single_value.get('nsds5replicaUpdateInProgress')
             status = entry.single_value.get('nsds5ReplicaLastUpdateStatus')
+            json_status = \
+                entry.single_value.get('nsds5ReplicaLastUpdateStatusjson')
             try:
                 # nsds5ReplicaLastUpdateStart is either a GMT time
                 # ending with Z or 0 (see 389-ds ticket 47836)
@@ -1130,11 +1152,19 @@ class ReplicationManager:
             except (ValueError, TypeError, KeyError):
                 end = 0
             # incremental update is done if inprogress is false and end >= start
-            done = inprogress and inprogress.lower() == 'false' and start <= end
+            done = inprogress is not None and not inprogress and start <= end
             logger.info("Replication Update in progress: %s: status: %s: "
                         "start: %d: end: %d",
                         inprogress, status, start, end)
-            if status: # always check for errors
+            if json_status:
+                # In 389-ds-base 1.4.1.4 we have the status message available
+                # to us in a json object
+                status_obj = json.loads(json_status)
+                if status_obj['state'] != 'green':
+                    hasError = 1
+                    error_message = status_obj['message']
+                    done = True
+            elif status:  # always check for errors
                 # status will usually be a number followed by a string
                 # number != 0 means error
                 # Since 389-ds-base 1.3.5 it is 'Error (%d) %s'
@@ -1337,7 +1367,7 @@ class ReplicationManager:
 
         try:
             self.conn.add_entry(entry)
-        except Exception as e:
+        except Exception:
             logger.info("Failed to create public entry for winsync replica")
 
         # For winsync, unhashed passwords needs to be in replication changelog
@@ -1564,12 +1594,12 @@ class ReplicationManager:
             pass
         except Exception as e:
             if force and err:
-                raise err   #pylint: disable=E0702
+                raise err
             else:
                 raise e
 
         if err:
-            raise err   #pylint: disable=E0702
+            raise err
 
     def set_readonly(self, readonly, critical=False):
         """
@@ -1799,7 +1829,7 @@ class ReplicationManager:
         Ensure that the 'cn=replication managers,cn=sysaccounts' group exists
         and contains the principals for master and remote replica
 
-        On FreeIPA 3.x masters lacking support for nsds5ReplicaBinddnGroup
+        On IPA 3.x masters lacking support for nsds5ReplicaBinddnGroup
         attribute, add replica bind DN directly into the replica entry.
         """
         my_dn = DN(
