@@ -304,7 +304,7 @@ class hbacrule_add(LDAPCreate):
     def pre_callback(self, ldap, dn, entry_attrs, attrs_list, *keys, **options):
         assert isinstance(dn, DN)
         # HBAC rules are enabled by default
-        entry_attrs['ipaenabledflag'] = 'TRUE'
+        entry_attrs['ipaenabledflag'] = True
         return dn
 
 
@@ -392,7 +392,7 @@ class hbacrule_enable(LDAPQuery):
         except errors.NotFound:
             raise self.obj.handle_not_found(cn)
 
-        entry_attrs['ipaenabledflag'] = ['TRUE']
+        entry_attrs['ipaenabledflag'] = [True]
 
         try:
             ldap.update_entry(entry_attrs)
@@ -422,7 +422,7 @@ class hbacrule_disable(LDAPQuery):
         except errors.NotFound:
             raise self.obj.handle_not_found(cn)
 
-        entry_attrs['ipaenabledflag'] = ['FALSE']
+        entry_attrs['ipaenabledflag'] = [False]
 
         try:
             ldap.update_entry(entry_attrs)
