@@ -24,13 +24,14 @@ from ipalib import api, errors
 from ipalib import Str, StrEnum, Bool, Int
 from ipalib.plugable import Registry
 from .baseldap import (LDAPObject, LDAPCreate, LDAPDelete,
-                                     LDAPUpdate, LDAPSearch, LDAPRetrieve,
-                                     LDAPQuery, LDAPAddMember, LDAPRemoveMember,
-                                     add_external_pre_callback,
-                                     add_external_post_callback,
-                                     remove_external_post_callback,
-                                     output, entry_to_dict, pkey_to_value,
-                                     external_host_param)
+                       LDAPUpdate, LDAPSearch, LDAPRetrieve,
+                       LDAPQuery, LDAPAddMember, LDAPRemoveMember,
+                       add_external_pre_callback,
+                       pre_callback_process_external_objects,
+                       add_external_post_callback,
+                       remove_external_post_callback,
+                       output, entry_to_dict, pkey_to_value,
+                       external_host_param)
 from .hbacrule import is_all
 from ipalib import _, ngettext
 from ipalib.util import validate_hostmask
@@ -47,7 +48,7 @@ give certain users (or groups of users) the ability to run some (or all)
 commands as root or another user while providing an audit trail of the
 commands and their arguments.
 """) + _("""
-FreeIPA provides a means to configure the various aspects of Sudo:
+IPA provides a means to configure the various aspects of Sudo:
    Users: The user(s)/group(s) allowed to invoke Sudo.
    Hosts: The host(s)/hostgroup(s) which the user is allowed to to invoke Sudo.
    Allow Command: The specific command(s) permitted to be run via Sudo.
@@ -56,16 +57,21 @@ FreeIPA provides a means to configure the various aspects of Sudo:
    RunAsGroup: The group(s) whose gid rights Sudo will be invoked with.
    Options: The various Sudoers Options that can modify Sudo's behavior.
 """) + _("""
+Each option needs to be added separately and no validation is done whether
+the option is known by sudo or is in a valid format. Environment variables
+also need to be set individually. For example env_keep="FOO BAR" in sudoers
+needs be represented as --sudooption env_keep=FOO --sudooption env_keep+=BAR.
+""") + _("""
 An order can be added to a sudorule to control the order in which they
 are evaluated (if the client supports it). This order is an integer and
 must be unique.
 """) + _("""
-FreeIPA provides a designated binddn to use with Sudo located at:
+IPA provides a designated binddn to use with Sudo located at:
 uid=sudo,cn=sysaccounts,cn=etc,dc=example,dc=com
 """) + _("""
 To enable the binddn run the following command to set the password:
 LDAPTLS_CACERT=/etc/ipa/ca.crt /usr/bin/ldappasswd -S -W \
--h ipa.example.com -ZZ -D "cn=Directory Manager" \
+-H ldap://ipa.example.com -ZZ -D "cn=Directory Manager" \
 uid=sudo,cn=sysaccounts,cn=etc,dc=example,dc=com
 """) + _("""
 EXAMPLES:
@@ -88,6 +94,10 @@ EXAMPLES:
 """) + _("""
  Set a default Sudo option:
    ipa sudorule-add-option defaults --sudooption '!authenticate'
+""") + _("""
+ Set multiple default Sudo options:
+   ipa sudorule-add-option defaults --sudooption '!authenticate' \
+   --sudooption mail_badpass
 """) + _("""
  Set SELinux type and role transitions on a rule:
    ipa sudorule-add-option sysadmin_sudo --sudooption type=unconfined_t
@@ -98,6 +108,11 @@ register = Registry()
 
 topic = 'sudo'
 
+# used to process external object references in SUDO rules
+USER_OBJ_SPEC = ('user', None)
+GROUP_OBJ_SPEC = ('group', '%')
+
+
 
 def deprecated(attribute):
     raise errors.ValidationError(
@@ -208,8 +223,8 @@ class sudorule(LDAPObject):
                 'ipasudorunasextuser', 'ipasudorunasextgroup', 'memberdenycmd',
                 'memberallowcmd', 'memberuser', 'memberhost', 'externalhost',
                 'sudonotafter', 'hostmask', 'sudoorder', 'sudonotbefore',
-                'ipasudorunas', 'externalhost', 'ipasudorunasgroup',
-                'ipasudoopt', 'memberhost',
+                'ipasudorunas', 'ipasudorunasgroup',
+                'ipasudoopt',
             },
             'replaces': [
                 '(targetattr = "description || ipaenabledflag || usercategory || hostcategory || cmdcategory || ipasudorunasusercategory || ipasudorunasgroupcategory || externaluser || ipasudorunasextuser || ipasudorunasextgroup || memberdenycmd || memberallowcmd || memberuser")(target = "ldap:///ipauniqueid=*,cn=sudorules,cn=sudo,$SUFFIX")(version 3.0;acl "permission:Modify Sudo rule";allow (write) groupdn = "ldap:///cn=Modify Sudo rule,cn=permissions,cn=pbac,$SUFFIX";)',
@@ -347,7 +362,7 @@ class sudorule(LDAPObject):
             label=_('RunAs External Group'),
             doc=_('External Group the commands can run as (sudorule-find only)'),
         ),
-        Str('ipasudoopt?',
+        Str('ipasudoopt*',
             label=_('Sudo Option'),
             flags=['no_create', 'no_update', 'no_search'],
         ),
@@ -382,7 +397,7 @@ class sudorule_add(LDAPCreate):
         assert isinstance(dn, DN)
         self.obj.check_order_uniqueness(*keys, **options)
         # Sudo Rules are enabled by default
-        entry_attrs['ipaenabledflag'] = 'TRUE'
+        entry_attrs['ipaenabledflag'] = True
         return dn
 
     msg_summary = _('Added Sudo Rule "%(value)s"')
@@ -404,21 +419,20 @@ class sudorule_mod(LDAPUpdate):
     def pre_callback(self, ldap, dn, entry_attrs, attrs_list, *keys, **options):
         assert isinstance(dn, DN)
 
-        if 'sudoorder' in options:
-            new_order = options.get('sudoorder')
-            old_entry = self.api.Command.sudorule_show(keys[-1])['result']
-            if 'sudoorder' in old_entry:
-                old_order = int(old_entry['sudoorder'][0])
-                if old_order != new_order:
-                    self.obj.check_order_uniqueness(*keys, **options)
-            else:
-                self.obj.check_order_uniqueness(*keys, **options)
-
         try:
             _entry_attrs = ldap.get_entry(dn, self.obj.default_attributes)
         except errors.NotFound:
             raise self.obj.handle_not_found(*keys)
 
+        if 'sudoorder' in options:
+            new_order = options.get('sudoorder')
+            if 'sudoorder' in _entry_attrs:
+                old_order = int(_entry_attrs['sudoorder'][0])
+                if old_order != new_order:
+                    self.obj.check_order_uniqueness(*keys, **options)
+            else:
+                self.obj.check_order_uniqueness(*keys, **options)
+
         error = _("%(type)s category cannot be set to 'all' "
                   "while there are allowed %(objects)s")
 
@@ -489,7 +503,7 @@ class sudorule_enable(LDAPQuery):
         except errors.NotFound:
             raise self.obj.handle_not_found(cn)
 
-        entry_attrs['ipaenabledflag'] = ['TRUE']
+        entry_attrs['ipaenabledflag'] = [True]
 
         try:
             ldap.update_entry(entry_attrs)
@@ -512,7 +526,7 @@ class sudorule_disable(LDAPQuery):
         except errors.NotFound:
             raise self.obj.handle_not_found(cn)
 
-        entry_attrs['ipaenabledflag'] = ['FALSE']
+        entry_attrs['ipaenabledflag'] = [False]
 
         try:
             ldap.update_entry(entry_attrs)
@@ -592,17 +606,40 @@ class sudorule_add_user(LDAPAddMember):
             raise errors.MutuallyExclusiveError(
                 reason=_("users cannot be added when user category='all'"))
 
-        return add_external_pre_callback('user', ldap, dn, keys, options)
+        for o_desc in (USER_OBJ_SPEC, GROUP_OBJ_SPEC):
+            dn = pre_callback_process_external_objects(
+                'memberuser', o_desc,
+                ldap, dn, found, not_found, *keys, **options)
+        return dn
 
     def post_callback(self, ldap, completed, failed, dn, entry_attrs,
                       *keys, **options):
         assert isinstance(dn, DN)
-        return add_external_post_callback(ldap, dn, entry_attrs,
-                                          failed=failed,
-                                          completed=completed,
-                                          memberattr='memberuser',
-                                          membertype='user',
-                                          externalattr='externaluser')
+
+        completed_ex = {}
+        completed_ex['user'] = 0
+        completed_ex['group'] = 0
+
+        # Since external_post_callback returns the total number of completed
+        # entries yet (that is, any external users it added plus the value of
+        # passed variable 'completed', we need to pass 0 as completed,
+        # so that the entries added by the framework are not counted twice
+        # (once in each call of add_external_post_callback)
+        for o_type in ('user', 'group'):
+            if o_type not in options:
+                continue
+
+            (completed_ex[o_type], dn) = \
+                add_external_post_callback(ldap, dn,
+                                           entry_attrs=entry_attrs,
+                                           failed=failed,
+                                           completed=0,
+                                           memberattr='memberuser',
+                                           membertype=o_type,
+                                           externalattr='externaluser',
+                                           )
+
+        return (completed + sum(completed_ex.values()), dn)
 
 
 @register()
@@ -612,15 +649,41 @@ class sudorule_remove_user(LDAPRemoveMember):
     member_attributes = ['memberuser']
     member_count_out = ('%i object removed.', '%i objects removed.')
 
+    def pre_callback(self, ldap, dn, found, not_found, *keys, **options):
+        assert isinstance(dn, DN)
+
+        for o_desc in (USER_OBJ_SPEC, GROUP_OBJ_SPEC):
+            dn = pre_callback_process_external_objects(
+                'memberuser', o_desc,
+                ldap, dn, found, not_found, *keys, **options)
+        return dn
+
     def post_callback(self, ldap, completed, failed, dn, entry_attrs,
                       *keys, **options):
         assert isinstance(dn, DN)
-        return remove_external_post_callback(ldap, dn, entry_attrs,
-                                             failed=failed,
-                                             completed=completed,
-                                             memberattr='memberuser',
-                                             membertype='user',
-                                             externalattr='externaluser')
+
+        # Since external_post_callback returns the total number of completed
+        # entries yet (that is, any external users it removed plus the value of
+        # passed variable 'completed', we need to pass 0 as completed,
+        # so that the entries removed by the framework are not counted twice
+        # (once in each call of remove_external_post_callback)
+        (completed_ex_users, dn) = remove_external_post_callback(
+            ldap, dn, entry_attrs,
+            failed=failed,
+            completed=0,
+            memberattr='memberuser',
+            membertype='user',
+            externalattr='externaluser')
+
+        (completed_ex_groups, dn) = remove_external_post_callback(
+            ldap, dn, entry_attrs,
+            failed=failed,
+            completed=0,
+            memberattr='memberuser',
+            membertype='group',
+            externalattr='externaluser')
+
+        return (completed + completed_ex_users + completed_ex_groups, dn)
 
 
 @register()
@@ -734,7 +797,7 @@ class sudorule_add_runasuser(LDAPAddMember):
     member_attributes = ['ipasudorunas']
     member_count_out = ('%i object added.', '%i objects added.')
 
-    def pre_callback(self, ldap, dn, entry_attrs, attrs_list, *keys, **options):
+    def pre_callback(self, ldap, dn, found, not_found, *keys, **options):
         assert isinstance(dn, DN)
 
         def check_validity(runas):
@@ -771,37 +834,39 @@ class sudorule_add_runasuser(LDAPAddMember):
                                           "'%(name)s' as a group name")) %
                                           dict(name=name))
 
-        return add_external_pre_callback('user', ldap, dn, keys, options)
+        for o_desc in (USER_OBJ_SPEC, GROUP_OBJ_SPEC):
+            dn = pre_callback_process_external_objects(
+                'ipasudorunas', o_desc,
+                ldap, dn, found, not_found, *keys, **options)
+        return dn
 
     def post_callback(self, ldap, completed, failed, dn, entry_attrs,
                       *keys, **options):
         assert isinstance(dn, DN)
 
+        completed_ex = {}
+        completed_ex['user'] = 0
+        completed_ex['group'] = 0
         # Since external_post_callback returns the total number of completed
         # entries yet (that is, any external users it added plus the value of
         # passed variable 'completed', we need to pass 0 as completed,
         # so that the entries added by the framework are not counted twice
         # (once in each call of add_external_post_callback)
+        for (o_type, ext_attr) in (('user', 'ipasudorunasextuser'),
+                                   ('group', 'ipasudorunasextusergroup')):
+            if o_type not in options:
+                continue
+            (completed_ex[o_type], dn) = \
+                add_external_post_callback(ldap, dn,
+                                           entry_attrs=entry_attrs,
+                                           failed=failed,
+                                           completed=0,
+                                           memberattr='ipasudorunas',
+                                           membertype=o_type,
+                                           externalattr=ext_attr,
+                                           )
 
-        (completed_ex_users, dn) = add_external_post_callback(ldap, dn,
-                                        entry_attrs,
-                                        failed=failed,
-                                        completed=0,
-                                        memberattr='ipasudorunas',
-                                        membertype='user',
-                                        externalattr='ipasudorunasextuser',
-                                        )
-
-        (completed_ex_groups, dn) = add_external_post_callback(ldap, dn,
-                                        entry_attrs=entry_attrs,
-                                        failed=failed,
-                                        completed=0,
-                                        memberattr='ipasudorunas',
-                                        membertype='group',
-                                        externalattr='ipasudorunasextusergroup',
-                                        )
-
-        return (completed + completed_ex_users + completed_ex_groups, dn)
+        return (completed + sum(completed_ex.values()), dn)
 
 
 @register()
@@ -811,35 +876,42 @@ class sudorule_remove_runasuser(LDAPRemoveMember):
     member_attributes = ['ipasudorunas']
     member_count_out = ('%i object removed.', '%i objects removed.')
 
+    def pre_callback(self, ldap, dn, found, not_found, *keys, **options):
+        assert isinstance(dn, DN)
+
+        for o_desc in (USER_OBJ_SPEC, GROUP_OBJ_SPEC):
+            dn = pre_callback_process_external_objects(
+                'ipasudorunas', o_desc,
+                ldap, dn, found, not_found, *keys, **options)
+        return dn
+
     def post_callback(self, ldap, completed, failed, dn, entry_attrs,
                       *keys, **options):
         assert isinstance(dn, DN)
 
+        completed_ex = {}
+        completed_ex['user'] = 0
+        completed_ex['group'] = 0
         # Since external_post_callback returns the total number of completed
         # entries yet (that is, any external users it added plus the value of
         # passed variable 'completed', we need to pass 0 as completed,
         # so that the entries added by the framework are not counted twice
-        # (once in each call of remove_external_post_callback)
+        # (once in each call of add_external_post_callback)
+        for (o_type, ext_attr) in (('user', 'ipasudorunasextuser'),
+                                   ('group', 'ipasudorunasextusergroup')):
+            if o_type not in options:
+                continue
+            (completed_ex[o_type], dn) = \
+                remove_external_post_callback(ldap, dn,
+                                              entry_attrs=entry_attrs,
+                                              failed=failed,
+                                              completed=0,
+                                              memberattr='ipasudorunas',
+                                              membertype=o_type,
+                                              externalattr=ext_attr,
+                                              )
 
-        (completed_ex_users, dn) = remove_external_post_callback(ldap, dn,
-                                        entry_attrs=entry_attrs,
-                                        failed=failed,
-                                        completed=0,
-                                        memberattr='ipasudorunas',
-                                        membertype='user',
-                                        externalattr='ipasudorunasextuser',
-                                        )
-
-        (completed_ex_groups, dn) = remove_external_post_callback(ldap, dn,
-                                        entry_attrs=entry_attrs,
-                                        failed=failed,
-                                        completed=0,
-                                        memberattr='ipasudorunas',
-                                        membertype='group',
-                                        externalattr='ipasudorunasextusergroup',
-                                        )
-
-        return (completed + completed_ex_users + completed_ex_groups, dn)
+        return (completed + sum(completed_ex.values()), dn)
 
 
 @register()
@@ -849,7 +921,7 @@ class sudorule_add_runasgroup(LDAPAddMember):
     member_attributes = ['ipasudorunasgroup']
     member_count_out = ('%i object added.', '%i objects added.')
 
-    def pre_callback(self, ldap, dn, entry_attrs, attrs_list, *keys, **options):
+    def pre_callback(self, ldap, dn, found, not_found, *keys, **options):
         assert isinstance(dn, DN)
 
         def check_validity(runas):
@@ -876,18 +948,21 @@ class sudorule_add_runasgroup(LDAPAddMember):
                                           "'%(name)s' as a group name")) %
                                           dict(name=name))
 
-        return add_external_pre_callback('group', ldap, dn, keys, options)
+        return pre_callback_process_external_objects(
+            'ipasudorunasgroup', GROUP_OBJ_SPEC,
+            ldap, dn, found, not_found, *keys, **options)
 
     def post_callback(self, ldap, completed, failed, dn, entry_attrs,
                       *keys, **options):
         assert isinstance(dn, DN)
-        return add_external_post_callback(ldap, dn, entry_attrs,
-                                          failed=failed,
-                                          completed=completed,
-                                          memberattr='ipasudorunasgroup',
-                                          membertype='group',
-                                          externalattr='ipasudorunasextgroup',
-                                          )
+        return add_external_post_callback(
+            ldap, dn, entry_attrs,
+            failed=failed,
+            completed=completed,
+            memberattr='ipasudorunasgroup',
+            membertype='group',
+            externalattr='ipasudorunasextgroup',
+        )
 
 
 @register()
@@ -897,16 +972,24 @@ class sudorule_remove_runasgroup(LDAPRemoveMember):
     member_attributes = ['ipasudorunasgroup']
     member_count_out = ('%i object removed.', '%i objects removed.')
 
+    def pre_callback(self, ldap, dn, found, not_found, *keys, **options):
+        assert isinstance(dn, DN)
+
+        return pre_callback_process_external_objects(
+            'ipasudorunasgroup', GROUP_OBJ_SPEC,
+            ldap, dn, found, not_found, *keys, **options)
+
     def post_callback(self, ldap, completed, failed, dn, entry_attrs,
                       *keys, **options):
         assert isinstance(dn, DN)
-        return remove_external_post_callback(ldap, dn, entry_attrs,
-                                          failed=failed,
-                                          completed=completed,
-                                          memberattr='ipasudorunasgroup',
-                                          membertype='group',
-                                          externalattr='ipasudorunasextgroup',
-                                          )
+        return remove_external_post_callback(
+            ldap, dn, entry_attrs,
+            failed=failed,
+            completed=completed,
+            memberattr='ipasudorunasgroup',
+            membertype='group',
+            externalattr='ipasudorunasextgroup',
+        )
 
 
 @register()
@@ -915,7 +998,7 @@ class sudorule_add_option(LDAPQuery):
 
     has_output = output.standard_entry
     takes_options = (
-        Str('ipasudoopt',
+        Str('ipasudoopt+',
             cli_name='sudooption',
             label=_('Sudo Option'),
         ),
@@ -926,16 +1009,17 @@ class sudorule_add_option(LDAPQuery):
 
         dn = self.obj.get_dn(cn)
 
-        if not options['ipasudoopt'].strip():
+        if len(options.get('ipasudoopt',[])) == 0:
             raise errors.EmptyModlist()
         entry_attrs = ldap.get_entry(dn, ['ipasudoopt'])
 
         try:
-            if options['ipasudoopt'] not in entry_attrs['ipasudoopt']:
-                entry_attrs.setdefault('ipasudoopt', []).append(
-                    options['ipasudoopt'])
-            else:
-                raise errors.DuplicateEntry
+            entry_attrs.setdefault('ipasudoopt', [])
+            for option in options['ipasudoopt']:
+                if option not in entry_attrs['ipasudoopt']:
+                    entry_attrs['ipasudoopt'].append(option)
+                else:
+                    raise errors.DuplicateEntry
         except KeyError:
             entry_attrs.setdefault('ipasudoopt', []).append(
                 options['ipasudoopt'])
@@ -963,7 +1047,7 @@ class sudorule_remove_option(LDAPQuery):
 
     has_output = output.standard_entry
     takes_options = (
-        Str('ipasudoopt',
+        Str('ipasudoopt+',
             cli_name='sudooption',
             label=_('Sudo Option'),
         ),
@@ -973,22 +1057,20 @@ class sudorule_remove_option(LDAPQuery):
         ldap = self.obj.backend
 
         dn = self.obj.get_dn(cn)
-
-        if not options['ipasudoopt'].strip():
+        if len(options.get('ipasudoopt',[])) == 0:
             raise errors.EmptyModlist()
 
         entry_attrs = ldap.get_entry(dn, ['ipasudoopt'])
 
         try:
-            if options['ipasudoopt'] in entry_attrs['ipasudoopt']:
-                entry_attrs.setdefault('ipasudoopt', []).remove(
-                    options['ipasudoopt'])
-                ldap.update_entry(entry_attrs)
-            else:
-                raise errors.AttrValueNotFound(
-                    attr='ipasudoopt',
-                    value=options['ipasudoopt']
-                    )
+            entry_attrs.setdefault('ipasudoopt', [])
+            for option in options['ipasudoopt']:
+                if option in entry_attrs['ipasudoopt']:
+                    entry_attrs['ipasudoopt'].remove(option)
+                else:
+                    raise errors.AttrValueNotFound(
+                        attr='ipasudoopt',
+                        value=option)
         except ValueError:
             pass
         except KeyError:
@@ -996,6 +1078,11 @@ class sudorule_remove_option(LDAPQuery):
                     attr='ipasudoopt',
                     value=options['ipasudoopt']
                     )
+
+        try:
+            ldap.update_entry(entry_attrs)
+        except errors.EmptyModlist:
+            pass
         except errors.NotFound:
             raise self.obj.handle_not_found(cn)
 
