@@ -12,7 +12,7 @@ from .baseldap import (
     LDAPRetrieve)
 from ipalib import _, ngettext
 from ipalib import output
-from ipalib.constants import DOMAIN_LEVEL_1
+from ipalib.constants import MIN_DOMAIN_LEVEL, DOMAIN_LEVEL_1
 from ipaserver.topology import (
     create_topology_graph, get_topology_connection_errors,
     map_masters_to_suffixes)
@@ -82,7 +82,11 @@ register = Registry()
 
 
 def validate_domain_level(api):
-    current = int(api.Command.domainlevel_get()['result'])
+    try:
+        current = int(api.Command.domainlevel_get()['result'])
+    except errors.NotFound:
+        current = MIN_DOMAIN_LEVEL
+
     if current < DOMAIN_LEVEL_1:
         raise errors.InvalidDomainLevelError(
             reason=_('Topology management requires minimum domain level {0} '
@@ -100,6 +104,7 @@ class topologysegment(LDAPObject):
     object_name = _('segment')
     object_name_plural = _('segments')
     object_class = ['iparepltoposegment']
+    permission_filter_objectclasses = ['iparepltoposegment', 'iparepltopoconf']
     default_attributes = [
         'cn',
         'ipaReplTopoSegmentdirection', 'ipaReplTopoSegmentrightNode',
@@ -111,6 +116,38 @@ class topologysegment(LDAPObject):
         'cn', 'ipaReplTopoSegmentdirection', 'ipaReplTopoSegmentrightNode',
         'ipaReplTopoSegmentLeftNode'
     ]
+    managed_permissions = {
+        'System: Read Topology Segments': {
+            'ipapermright': {'read', 'search', 'compare'},
+            'ipapermdefaultattr': {
+                'cn', 'objectclass',
+                'ipaReplTopoSegmentdirection', 'ipaReplTopoSegmentrightNode',
+                'ipaReplTopoSegmentLeftNode', 'ipaReplTopoConfRoot',
+                'ipaReplTopoSegmentStatus','nsds5replicastripattrs',
+                'nsds5replicatedattributelist',
+                'nsds5replicatedattributelisttotal',
+            },
+            'default_privileges': {'Replication Administrators'},
+        },
+        'System: Add Topology Segments': {
+            'ipapermright': {'add'},
+            'default_privileges': {'Replication Administrators'},
+        },
+        'System: Remove Topology Segments': {
+            'ipapermright': {'delete'},
+            'default_privileges': {'Replication Administrators'},
+        },
+        'System: Modify Topology Segments': {
+            'ipapermright': {'write'},
+            'ipapermdefaultattr': {
+                'ipaReplTopoSegmentdirection', 'ipaReplTopoSegmentrightNode',
+                'ipaReplTopoSegmentLeftNode', 'nsds5replicastripattrs',
+                'nsds5replicatedattributelist',
+                'nsds5replicatedattributelisttotal',
+            },
+            'default_privileges': {'Replication Administrators'},
+        },
+    }
 
     label = _('Topology Segments')
     label_singular = _('Topology Segment')
