@@ -16,6 +16,8 @@ tests_result=1
     --logfile-dir="$IPA_TESTS_LOGSDIR" \
     --with-xunit \
     --verbose \
+    -ra \
+    $IPA_TESTS_ARGS \
     $IPA_TESTS_TO_IGNORE \
     $IPA_TESTS_TO_RUN && tests_result=0 ; } || \
     tests_result=$?
@@ -26,13 +28,4 @@ chmod -R o+rX "$IPA_TESTS_LOGSDIR"
 find "$IPA_TESTS_LOGSDIR" -mindepth 1 -maxdepth 1 -not -name '.*' -type d \
     -exec tar --remove-files -czf {}.tar.gz {} \;
 
-echo "Report memory statistics"
-cat /sys/fs/cgroup/memory/memory.memsw.failcnt
-cat /sys/fs/cgroup/memory/memory.memsw.limit_in_bytes
-cat /sys/fs/cgroup/memory/memory.memsw.max_usage_in_bytes
-cat /sys/fs/cgroup/memory/memory.failcnt
-cat /sys/fs/cgroup/memory/memory.max_usage_in_bytes
-cat /sys/fs/cgroup/memory/memory.limit_in_bytes
-cat /proc/sys/vm/swappiness
-
 exit $tests_result
