@@ -52,7 +52,7 @@ def enable_userspace_fips(host):
         ["openssl", "md5", "/dev/null"], raiseonerr=False
     )
     assert result.returncode == 1
-    assert "EVP_DigestInit_ex:disabled for FIPS" in result.stderr_text
+    assert "Error setting digest" in result.stderr_text
 
 
 def disable_userspace_fips(host):
@@ -68,3 +68,9 @@ def disable_userspace_fips(host):
     # sanity check
     assert not is_fips_enabled(host)
     host.run_command(["openssl", "md5", "/dev/null"])
+
+
+def enable_crypto_subpolicy(host, subpolicy):
+    result = host.run_command(["update-crypto-policies", "--show"])
+    policy = result.stdout_text.strip() + ":" + subpolicy
+    host.run_command(["update-crypto-policies", "--set", policy])
