@@ -20,7 +20,6 @@ from __future__ import absolute_import
 import os
 import re
 import time
-import tempfile
 
 from cryptography import x509
 from cryptography.hazmat.backends import default_backend
@@ -82,6 +81,7 @@ def install_server_external_ca_step1(host, extra_args=(), raiseonerr=True):
 
 
 def install_server_external_ca_step2(host, ipa_ca_cert, root_ca_cert,
+                                     extra_args=(),
                                      raiseonerr=True):
     """Step 2 to install the ipa server with external ca"""
     args = ['ipa-server-install', '-U', '-r', host.domain.realm,
@@ -89,7 +89,7 @@ def install_server_external_ca_step2(host, ipa_ca_cert, root_ca_cert,
             '-p', host.config.dirman_password,
             '--external-cert-file', ipa_ca_cert,
             '--external-cert-file', root_ca_cert]
-
+    args.extend(extra_args)
     cmd = host.run_command(args, raiseonerr=raiseonerr)
     return cmd
 
@@ -115,7 +115,30 @@ def check_mscs_extension(ipa_csr, template):
         if ext.oid.dotted_string == template.ext_oid
     ]
     assert extensions
-    assert extensions[0].value.value == template.get_ext_data()
+    mscs_ext = extensions[0].value
+
+    # Crypto 41.0.0 supports cryptography.x509.MSCertificateTemplate
+    # The extension gets decoded into MSCertificateTemplate which
+    # provides additional attributes (template_id, major_minor and
+    # minor_version)
+    # If the test is executed with an older python-cryptography version,
+    # the extension is decoded as UnrecognizedExtension instead and
+    # provides only the encoded payload
+    if isinstance(mscs_ext, x509.UnrecognizedExtension):
+        assert mscs_ext.value == template.get_ext_data()
+    else:
+        # Compare the decoded extension with the values specified in the
+        # template with a format name_or_oid:major:minor
+        parts = template.unparsed_input.split(':')
+        assert mscs_ext.template_id.dotted_string == parts[0]
+
+        if isinstance(template, ipa_x509.MSCSTemplateV2):
+            # Also contains OID:major[:minor]
+            major = int(parts[1])
+            assert major == mscs_ext.major_version
+            if len(parts) > 2:
+                minor = int(parts[2])
+                assert minor == mscs_ext.minor_version
 
 
 class TestExternalCA(IntegrationTest):
@@ -301,7 +324,7 @@ class TestSelfExternalSelf(IntegrationTest):
     def test_switch_back_to_self_signed(self):
 
         # for journalctl --since
-        switch_time = time.strftime('%H:%M:%S')
+        switch_time = time.strftime('%Y-%m-%d %H:%M:%S')
         # switch back to self-signed CA
         result = self.master.run_command([paths.IPA_CACERT_MANAGE, 'renew',
                                           '--self-signed'])
@@ -464,8 +487,12 @@ class TestMultipleExternalCA(IntegrationTest):
     def test_master_install_ca1(self):
         install_server_external_ca_step1(self.master)
         # Sign CA, transport it to the host and get ipa a root ca paths.
-        root_ca_fname1 = tempfile.mkdtemp(suffix='root_ca.crt', dir=paths.TMP)
-        ipa_ca_fname1 = tempfile.mkdtemp(suffix='ipa_ca.crt', dir=paths.TMP)
+        root_ca_fname1 = tasks.create_temp_file(
+            self.master, directory=paths.TMP, suffix="root_ca.crt"
+        )
+        ipa_ca_fname1 = tasks.create_temp_file(
+            self.master, directory=paths.TMP, suffix="ipa_ca.crt"
+        )
 
         ipa_csr = self.master.get_file_contents(paths.ROOT_IPA_CSR)
 
@@ -485,8 +512,12 @@ class TestMultipleExternalCA(IntegrationTest):
         assert "CN=RootCA1" in result.stdout_text
 
     def test_master_install_ca2(self):
-        root_ca_fname2 = tempfile.mkdtemp(suffix='root_ca.crt', dir=paths.TMP)
-        ipa_ca_fname2 = tempfile.mkdtemp(suffix='ipa_ca.crt', dir=paths.TMP)
+        root_ca_fname2 = tasks.create_temp_file(
+            self.master, directory=paths.TMP, suffix="root_ca.crt"
+        )
+        ipa_ca_fname2 = tasks.create_temp_file(
+            self.master, directory=paths.TMP, suffix="ipa_ca.crt"
+        )
 
         self.master.run_command([
             paths.IPA_CACERT_MANAGE, 'renew', '--external-ca'])
