@@ -152,6 +152,12 @@ class TestSudo(IntegrationTest):
             assert result1.returncode == 0 and result2.returncode == 0,\
                 'rules cleanup failed'
 
+    @pytest.mark.skip_if_platform(
+        "debian", reason="NISDOMAIN has not been set on Debian"
+    )
+    @pytest.mark.skip_if_container(
+        "any", reason="NISDOMAIN cannot be set in containerized environment"
+    )
     def test_nisdomainname(self):
         result = self.client.run_command('nisdomainname')
         assert self.client.domain.name in result.stdout_text
@@ -164,6 +170,11 @@ class TestSudo(IntegrationTest):
         # No group
         self.master.run_command(['ipa', 'sudocmd-add', '/usr/bin/yum'])
 
+        # Invalid command
+        result = self.master.run_command(
+            ['ipa', 'sudocmd-add', '/bin/cat.'], raiseonerr=False)
+        assert result.returncode == 1
+
     def test_add_sudo_command_groups(self):
         self.master.run_command(['ipa', 'sudocmdgroup-add', 'readers',
                                  '--desc', '"Applications that read"'])
