@@ -21,8 +21,6 @@
 Test the `ipalib.frontend` module.
 """
 
-# FIXME: Pylint errors
-# pylint: disable=no-member
 import pytest
 import six
 
@@ -71,7 +69,7 @@ def test_is_rule():
     is_rule = frontend.is_rule
     flag = frontend.RULE_FLAG
 
-    class no_call(object):
+    class no_call:
         def __init__(self, value):
             if value is not None:
                 assert value in (True, False)
@@ -199,7 +197,7 @@ class test_Command(ClassChecker):
         """
         Return a standard subclass of `ipalib.frontend.Command`.
         """
-        class Rule(object):
+        class Rule:
             def __init__(self, name):
                 self.name = name
 
@@ -213,7 +211,9 @@ class test_Command(ClassChecker):
                 lambda arg: arg,
                 'default_from'
         )
-        normalizer = lambda value: value.lower()
+
+        def normalizer(value):
+            return value.lower()
 
         class example(self.cls):
             takes_options = (
@@ -232,7 +232,7 @@ class test_Command(ClassChecker):
         """
         Helper method used to test args and options.
         """
-        class api(object):
+        class api:
             @staticmethod
             def is_production_mode():
                 return False
@@ -278,7 +278,7 @@ class test_Command(ClassChecker):
         """
         Test the ``ipalib.frontend.Command.args`` instance attribute.
         """
-        class api(object):
+        class api:
             @staticmethod
             def is_production_mode():
                 return False
@@ -335,7 +335,7 @@ class test_Command(ClassChecker):
         """
         Test the ``ipalib.frontend.Command.options`` instance attribute.
         """
-        class api(object):
+        class api:
             @staticmethod
             def is_production_mode():
                 return False
@@ -359,7 +359,7 @@ class test_Command(ClassChecker):
         """
         Test the ``ipalib.frontend.Command.output`` instance attribute.
         """
-        class api(object):
+        class api:
             @staticmethod
             def is_production_mode():
                 return False
@@ -367,7 +367,9 @@ class test_Command(ClassChecker):
         inst.finalize()
         assert type(inst.output) is NameSpace
         assert list(inst.output) == ['result']
+        # pylint: disable=no-member
         assert type(inst.output.result) is output.Output
+        # pylint: enable=no-member
 
     def test_iter_output(self):
         """
@@ -407,7 +409,7 @@ class test_Command(ClassChecker):
         """
         Test the `ipalib.frontend.Command.convert` method.
         """
-        class api(object):
+        class api:
             @staticmethod
             def is_production_mode():
                 return False
@@ -424,7 +426,7 @@ class test_Command(ClassChecker):
         """
         Test the `ipalib.frontend.Command.normalize` method.
         """
-        class api(object):
+        class api:
             @staticmethod
             def is_production_mode():
                 return False
@@ -463,7 +465,7 @@ class test_Command(ClassChecker):
         api.finalize()
         o = my_cmd(api)
         o.finalize()
-        e = o.get_default(**kw)  # pylint: disable=not-callable
+        e = o.get_default(**kw)
         assert type(e) is dict
         assert 'option2' in e
         assert e['option2'] == u'some value'
@@ -472,7 +474,7 @@ class test_Command(ClassChecker):
         """
         Test the `ipalib.frontend.Command.validate` method.
         """
-        class api(object):
+        class api:
             env = config.Env(context='cli')
             @staticmethod
             def is_production_mode():
@@ -691,7 +693,7 @@ class test_Command(ClassChecker):
         """
         Test the `ipalib.frontend.Command.validate_output` method.
         """
-        class api(object):
+        class api:
             @staticmethod
             def is_production_mode():
                 return False
@@ -733,7 +735,7 @@ class test_Command(ClassChecker):
         """
         Test `ipalib.frontend.Command.validate_output` per-type validation.
         """
-        class api(object):
+        class api:
             @staticmethod
             def is_production_mode():
                 return False
@@ -762,7 +764,7 @@ class test_Command(ClassChecker):
         """
         Test `ipalib.frontend.Command.validate_output` nested validation.
         """
-        class api(object):
+        class api:
             @staticmethod
             def is_production_mode():
                 return False
@@ -797,7 +799,7 @@ class test_Command(ClassChecker):
         """
         Test the `ipalib.frontend.Command.get_output_params` method.
         """
-        class api(object):
+        class api:
             @staticmethod
             def is_production_mode():
                 return False
@@ -833,7 +835,7 @@ class test_LocalOrRemote(ClassChecker):
         """
         Test the `ipalib.frontend.LocalOrRemote.__init__` method.
         """
-        class api(object):
+        class api:
             @staticmethod
             def is_production_mode():
                 return False
@@ -916,7 +918,7 @@ class test_Object(ClassChecker):
         Test the `ipalib.frontend.Object.__init__` method.
         """
         # Setup for test:
-        class DummyAttribute(object):
+        class DummyAttribute:
             def __init__(self, obj_name, attr_name, name=None):
                 self.obj_name = obj_name
                 self.attr_name = attr_name
@@ -944,7 +946,7 @@ class test_Object(ClassChecker):
         cnt = 10
         methods_format = 'method_%d'
 
-        class FakeAPI(object):
+        class FakeAPI:
             def __init__(self):
                 self._API__plugins = get_attributes(cnt, methods_format)
                 self._API__default_map = {}
@@ -1113,13 +1115,16 @@ class test_Attribute(ClassChecker):
         Test the `ipalib.frontend.Attribute.__init__` method.
         """
         user_obj = 'The user frontend.Object instance'
-        class api(object):
+
+        class api:
             Object = {("user", "1"): user_obj}
             @staticmethod
             def is_production_mode():
                 return False
+
         class user_add(self.cls):
             pass
+
         o = user_add(api)
         assert read_only(o, 'api') is api
         assert read_only(o, 'obj') is user_obj
