@@ -31,12 +31,11 @@ import re
 import sys
 from decimal import Decimal
 from inspect import isclass
+from xmlrpc.client import MAXINT, MININT
+
 import pytest
 
 import six
-# pylint: disable=import-error
-from six.moves.xmlrpc_client import MAXINT, MININT
-# pylint: enable=import-error
 from cryptography import x509 as crypto_x509
 from cryptography.hazmat.backends import default_backend
 
@@ -47,6 +46,7 @@ from ipalib import parameters, text, errors, config, x509
 from ipalib.constants import TYPE_ERROR, CALLABLE_ERROR
 from ipalib.errors import ValidationError, ConversionError
 from ipalib import _
+from ipapython.dn import DN
 
 if six.PY3:
     unicode = str
@@ -73,8 +73,7 @@ class test_DefaultFrom(ClassChecker):
         o = self.cls(callback, *keys)
         assert read_only(o, 'callback') is callback
         assert read_only(o, 'keys') == keys
-        lam = lambda first, last: first[0] + last
-        o = self.cls(lam)
+        o = self.cls(lambda first, last: first[0] + last)
         assert read_only(o, 'keys') == ('first', 'last')
 
         # Test that TypeError is raised when callback isn't callable:
@@ -108,7 +107,8 @@ class test_DefaultFrom(ClassChecker):
         o = self.cls(stuff, 'aye', 'bee', 'see')
         assert repr(o) == "DefaultFrom('aye', 'bee', 'see')"
 
-        cb = lambda first, last: first[0] + last
+        def cb(first, last):
+            return first[0] + last
 
         o = self.cls(cb)
         assert repr(o) == "DefaultFrom('first', 'last')"
@@ -173,7 +173,7 @@ def test_parse_param_spec():
     assert str(e) == TYPE_ERROR % ('spec', str, bad_value, type(bad_value))
 
 
-class DummyRule(object):
+class DummyRule:
     def __init__(self, error=None):
         assert error is None or type(error) is unicode
         self.error = error
@@ -293,7 +293,9 @@ class test_Param(ClassChecker):
         )
 
         # Test that default_from gets set:
-        call = lambda first, last: first[0] + last
+        def call(first, last):
+            return first[0] + last
+
         o = self.cls('my_param', default_from=call)
         assert type(o.default_from) is parameters.DefaultFrom
         assert o.default_from.callback is call
@@ -346,6 +348,12 @@ class test_Param(ClassChecker):
             assert_equal(p.safe_value(value), u'********')
         assert p.safe_value(None) is None
 
+    def test_password_whitespaces(self):
+        values = ('Secret123', ' Secret123', 'Secret123 ', ' Secret123 ',)
+        p = parameters.Password('my_passwd')
+        for value in values:
+            assert(p.validate(value)) is None
+
     def test_clone(self):
         """
         Test the `ipalib.parameters.Param.clone` method.
@@ -581,7 +589,7 @@ class test_Param(ClassChecker):
         """
         Test the `ipalib.parameters.Param.get_default` method.
         """
-        class PassThrough(object):
+        class PassThrough:
             value = None
 
             def __call__(self, value):
@@ -599,7 +607,7 @@ class test_Param(ClassChecker):
 
             def __init__(self, name, **kw):
                 # (Pylint complains because the superclass is unknowm)
-                # pylint: disable=bad-super-call, super-on-old-class
+                # pylint: disable=super-on-old-class
                 self._convert_scalar = PassThrough()
                 super(Str, self).__init__(name, **kw)
 
@@ -681,7 +689,7 @@ class test_Data(ClassChecker):
         Test the `ipalib.parameters.Data.__init__` method.
         """
         o = self.cls('my_data')
-        assert o.type is type(None)
+        assert o.type is type(None)  # noqa
         assert o.password is False
         assert o.rules == tuple()
         assert o.class_rules == tuple()
@@ -1222,7 +1230,7 @@ class test_Number(ClassChecker):
         Test the `ipalib.parameters.Number.__init__` method.
         """
         o = self.cls('my_number')
-        assert o.type is type(None)
+        assert o.type is type(None)  # noqa
         assert o.password is False
         assert o.rules == tuple()
         assert o.class_rules == tuple()
@@ -1243,7 +1251,7 @@ class test_Int(ClassChecker):
         # Test with no kwargs:
         o = self.cls('my_number')
         assert o.type == int
-        assert o.allowed_types == six.integer_types
+        assert o.allowed_types == (int,)
         assert isinstance(o, parameters.Int)
         assert o.minvalue == int(MININT)
         assert o.maxvalue == int(MAXINT)
@@ -1312,6 +1320,23 @@ class test_Int(ClassChecker):
         param = self.cls('my_number')
         check_int_scalar_conversions(param)
 
+    def test_safe_json(self):
+        param = self.cls(
+            "large",
+            minvalue=self.cls.MIN_SAFE_INTEGER,
+            maxvalue=self.cls.MAX_SAFE_INTEGER
+        )
+        for value in (-((2 ** 53) - 1), 0, (2 ** 53) - 1):
+            param.validate(value)
+        for value in (-2 ** 53, 2 ** 53):
+            with pytest.raises(errors.ValidationError):
+                param.validate(value)
+
+        with pytest.raises(ValueError):
+            self.cls("toolarge", maxvalue=2**53)
+        with pytest.raises(ValueError):
+            self.cls("toosmall", minvalue=-2**53)
+
 
 class test_Decimal(ClassChecker):
     """
@@ -1751,3 +1776,128 @@ class test_CertificateSigningRequest(ClassChecker):
         # test that wrong type will not be accepted
         bad_value = datetime.date.today()
         raises(ConversionError, o.convert, bad_value)
+
+
+class test_DNParam(ClassChecker):
+    """
+    Test the `ipalib.parameters.DN` class.
+    """
+    _cls = parameters.DNParam
+
+    def test_init(self):
+        """
+        Test the `ipalib.parameters.DN.__init__` method.
+        """
+        o = self.cls('my_dn')
+        assert o.type is DN
+        assert o.password is False
+
+    def test_convert_scalar(self):
+        """
+        Test the `ipalib.parameters.DNParam._convert_scalar` method.
+        """
+        o = self.cls('my_dn')
+        mthd = o._convert_scalar
+        # param can be built from a string or from a DN
+        good = [
+            'cn=dn,cn=suffix',
+            DN('cn=dn,cn=suffix')
+        ]
+        for value in good:
+            assert mthd(value) == DN(value)
+        # param cannot be built from a tuple or list if single-valued
+        bad = [
+            ['cn=dn,cn=suffix'],
+            ['cn=dn', 'cn=suffix'],
+            ('cn=dn', 'cn=suffix'),
+            (('cn', 'dn'), ('cn', 'suffix'))
+        ]
+        for value in bad:
+            e = raises(errors.ConversionError, mthd, value)
+            assert e.name == 'my_dn'
+            assert_equal(unicode(e.error), u'Only one value is allowed')
+        assert o.convert(None) is None
+
+    def test_convert_singlevalued(self):
+        """
+        Test the `DNParam.convert` method  with a single-valued param.
+        """
+        o = self.cls('my_dn?')
+        mthd = o.convert
+        # param can be built from a string or from a DN
+        good = [
+            'cn=dn,cn=suffix',
+            DN('cn=dn,cn=suffix')
+        ]
+        for value in good:
+            assert mthd(value) == DN(value)
+        # param cannot be built from a tuple or list if single-valued
+        bad = [
+            ['cn=dn,cn=suffix'],
+            ['cn=dn', 'cn=suffix'],
+            ('cn=dn', 'cn=suffix'),
+            (('cn', 'dn'), ('cn', 'suffix'))
+        ]
+        for value in bad:
+            e = raises(errors.ConversionError, mthd, value)
+            assert e.name == 'my_dn'
+            assert_equal(unicode(e.error), u'Only one value is allowed')
+        assert o.convert(None) is None
+
+    def test_convert_multivalued(self):
+        """
+        Test the `DNParam.convert` method with a multivalued param.
+        """
+        o = self.cls('my_dn*')
+        mthd = o.convert
+        # param can be built from a tuple/list
+        good = [
+            ('cn=dn1,cn=suffix',),
+            ('cn=dn1,cn=suffix', 'cn=dn2,cn=suffix'),
+            ['cn=dn1,cn=suffix'],
+            ['cn=dn1,cn=suffix', 'cn=dn2,cn=suffix'],
+        ]
+        for value in good:
+            assert mthd(value) == tuple(DN(oneval) for oneval in value)
+        assert o.convert(None) is None
+
+
+class test_SerialNumber(ClassChecker):
+    """
+    Test the `ipalib.parameters.SerialNumber` class.
+    """
+    _cls = parameters.SerialNumber
+
+    def test_init(self):
+        """
+        Test the `ipalib.parameters.SerialNumber.__init__` method.
+        """
+        o = self.cls('my_serial')
+        assert o.type is str
+        assert o.length is None
+
+    def test_validate_scalar(self):
+        """
+        Test the `ipalib.parameters.SerialNumber._convert_scalar` method.
+        """
+        o = self.cls('my_serial')
+        mthd = o._validate_scalar
+        for value in ('1234', '0xabcd', '0xABCD'):
+            assert mthd(value) is None
+        bad = ['Hello', '123A']
+        for value in bad:
+            e = raises(errors.ValidationError, mthd, value)
+            assert e.name == 'my_serial'
+            assert_equal(e.error, 'must be an integer')
+        bad = ['-1234', '-0xAFF']
+        for value in bad:
+            e = raises(errors.ValidationError, mthd, value)
+            assert e.name == 'my_serial'
+            assert_equal(e.error, 'must be at least 0')
+        bad = ['0xGAH', '0x',]
+        for value in bad:
+            e = raises(errors.ValidationError, mthd, value)
+            assert e.name == 'my_serial'
+            assert_equal(
+                e.error, 'invalid valid hex'
+            )
