@@ -25,7 +25,6 @@ from __future__ import print_function
 import os
 import shutil
 import tempfile
-import unittest
 
 import six
 import pytest
@@ -50,7 +49,7 @@ def test_create_translation():
     assert context.__dict__[key] is t
 
 
-class test_TestLang(object):
+class test_TestLang:
     lang_env_vars = {'LC_ALL', 'LC_MESSAGES', 'LANGUAGE', 'LANG'}
 
     def setup_lang(self):
@@ -77,7 +76,8 @@ class test_TestLang(object):
 
         os.environ.update(self.saved_locale)
 
-    def setup(self):
+    @pytest.fixture(autouse=True)
+    def testlang_setup(self, request):
         self.tmp_dir = None
         self.setup_lang()
 
@@ -102,26 +102,27 @@ class test_TestLang(object):
 
         result = create_po(self.pot_file, self.po_file, self.mo_file)
         if result:
-            raise unittest.SkipTest(
+            pytest.skip(
                 'Unable to create po file "%s" & mo file "%s" from pot '
                 'file "%s"' % (self.po_file, self.mo_file, self.pot_file)
             )
 
         if not os.path.isfile(self.po_file):
-            raise unittest.SkipTest(
+            pytest.skip(
                 'Test po file unavailable: {}'.format(self.po_file))
 
         if not os.path.isfile(self.mo_file):
-            raise unittest.SkipTest(
+            pytest.skip(
                 'Test mo file unavailable: {}'.format(self.mo_file))
 
         self.po_file_iterate = po_file_iterate
 
-    def teardown(self):
-        self.teardown_lang()
+        def fin():
+            self.teardown_lang()
 
-        if self.tmp_dir is not None:
-            shutil.rmtree(self.tmp_dir)
+            if self.tmp_dir is not None:
+                shutil.rmtree(self.tmp_dir)
+        request.addfinalizer(fin)
 
     def test_test_lang(self):
         print("test_test_lang")
@@ -148,7 +149,8 @@ class test_TestLang(object):
         result = self.po_file_iterate(self.po_file, get_msgstr, get_msgstr_plural)
         assert result == 0
 
-class test_LazyText(object):
+
+class test_LazyText:
 
     klass = text.LazyText
 
@@ -159,7 +161,7 @@ class test_LazyText(object):
         assert inst.key == ('foo', 'bar')
 
 
-class test_FixMe(object):
+class test_FixMe:
     klass = text.FixMe
 
     def test_init(self):
@@ -178,7 +180,7 @@ class test_FixMe(object):
         assert type(unicode(inst)) is unicode
 
 
-class test_Gettext(object):
+class test_Gettext:
 
     klass = text.Gettext
 
@@ -186,7 +188,7 @@ class test_Gettext(object):
         inst = self.klass('what up?', 'foo', 'bar')
         assert inst.domain == 'foo'
         assert inst.localedir == 'bar'
-        assert inst.msg is 'what up?'
+        assert inst.msg == 'what up?'
         assert inst.args == ('what up?', 'foo', 'bar')
 
     def test_repr(self):
@@ -241,7 +243,7 @@ class test_Gettext(object):
         assert (inst4 != inst1) is True
 
 
-class test_NGettext(object):
+class test_NGettext:
 
     klass = text.NGettext
 
@@ -320,7 +322,7 @@ class test_NGettext(object):
         assert (inst4 != inst1) is True
 
 
-class test_GettextFactory(object):
+class test_GettextFactory:
 
     klass = text.GettextFactory
 
@@ -348,12 +350,12 @@ class test_GettextFactory(object):
         inst = self.klass('foo', 'bar')
         g = inst('what up?')
         assert type(g) is text.Gettext
-        assert g.msg is 'what up?'
+        assert g.msg == 'what up?'
         assert g.domain == 'foo'
         assert g.localedir == 'bar'
 
 
-class test_NGettextFactory(object):
+class test_NGettextFactory:
 
     klass = text.NGettextFactory
 
@@ -387,7 +389,7 @@ class test_NGettextFactory(object):
         assert ng.localedir == 'bar'
 
 
-class test_ConcatenatedText(object):
+class test_ConcatenatedText:
 
     klass = text.ConcatenatedLazyText
 
