@@ -21,6 +21,7 @@
 Service tests
 """
 
+from ipatests.test_webui.crypto_utils import generate_certificate, generate_csr
 from ipatests.test_webui.ui_driver import UI_driver
 from ipatests.test_webui.ui_driver import screenshot
 import pytest
@@ -147,21 +148,17 @@ class test_service(sevice_tasks):
         """
         Test service certificate actions
 
-        Requires to have CA installed and 'service_csr_path' configuration
-        option set.
+        Requires to have CA installed.
         """
 
         if not self.has_ca():
             self.skip('CA is not configured')
 
-        csr_path = self.config.get('service_csr_path')
-        if not csr_path:
-            self.skip('CSR file is not configured')
-
         self.init_app()
         data = self.prep_data()
         pkey = data.get('pkey')
-        csr = self.load_file(csr_path)
+        hostname = self.config.get('ipa_server')
+        csr = generate_csr(hostname)
         cert_widget_sel = "div.certificate-widget"
 
         self.add_record(ENTITY, data)
@@ -178,6 +175,8 @@ class test_service(sevice_tasks):
         self.wait_for_request(n=2, d=3)
         self.assert_visible(cert_widget_sel)
 
+        widget = self.find(cert_widget_sel, By.CSS_SELECTOR)
+
         # cert view
         self.action_list_action('view', confirm=False,
                                 parents_css_sel=cert_widget_sel)
@@ -218,7 +217,8 @@ class test_service(sevice_tasks):
         self.wait()
         self.select('select', '6')
         self.dialog_button_click('ok')
-        self.wait_for_request(n=2, d=3)
+        self.wait_while_working(widget)
+
         self.assert_visible(cert_widget_sel + " div.watermark")
 
         # check that revoke action is not enabled
@@ -241,7 +241,7 @@ class test_service(sevice_tasks):
                                 parents_css_sel=cert_widget_sel)
         self.wait()
         self.dialog_button_click('ok')
-        self.wait_for_request(n=2)
+        self.wait_while_working(widget)
 
         # check that revoke action is enabled
         self.assert_action_list_action('revoke',
@@ -266,6 +266,8 @@ class test_service(sevice_tasks):
         self.wait()
         self.select('select', '1')
         self.dialog_button_click('ok')
+        self.close_notifications()
+        self.wait_while_working(widget)
 
         # check that revoke action is not enabled
         self.assert_action_list_action('revoke', enabled=False,
@@ -285,20 +287,16 @@ class test_service(sevice_tasks):
     def test_arbitrary_certificates(self):
         """
         Test managing service arbitrary certificate.
-
-        Requires to have 'arbitrary_cert_path' configuration set.
         """
-        cert_path = self.config.get('arbitrary_cert_path')
-        if not cert_path:
-            self.skip('Arbitrary certificate file is not configured')
-
         self.init_app()
         data = self.prep_data()
         pkey = data.get('pkey')
-        cert = self.load_file(cert_path)
+        hostname = self.config.get('ipa_server')
+        cert = generate_certificate(hostname)
         cert_widget_sel = "div.certificate-widget"
 
         self.add_record(ENTITY, data)
+        self.close_notifications()
         self.navigate_to_record(pkey)
 
         # check whether certificate section is present
@@ -306,9 +304,9 @@ class test_service(sevice_tasks):
 
         # add certificate
         self.button_click('add', parents_css_sel="div[name='certificate']")
-        self.assert_dialog()
+        self.assert_dialog('cert-add-dialog')
         self.fill_textarea('new_cert', cert)
-        self.dialog_button_click('add')
+        self.dialog_button_click('ok')
 
         self.assert_visible(cert_widget_sel)
 
@@ -626,11 +624,8 @@ class test_service(sevice_tasks):
         if not self.has_ca():
             self.skip('CA is not configured')
 
-        csr_path = self.config.get('service_csr_path')
-        if not csr_path:
-            self.skip('CSR file is not configured')
-
-        csr = self.load_file(csr_path)
+        hostname = self.config.get('ipa_server')
+        csr = generate_csr(hostname)
 
         self.init_app()
         pkey = self.get_service_pkey('cifs')
