@@ -184,6 +184,25 @@ class test_config(Declarative):
                 ),
         ),
 
+        dict(
+            desc='Set user auth type to passkey',
+            command=('config_mod', [], dict(ipauserauthtype=u'passkey')),
+            expected=dict(
+                result=lambda d: d['ipauserauthtype'] == (u'passkey',),
+                value=None,
+                summary=None,
+            ),
+        ),
+
+        dict(
+            desc='Check user auth type is passkey',
+            command=('config_show', [], {}),
+            expected=dict(
+                result=lambda d: d['ipauserauthtype'] == (u'passkey',),
+                value=None,
+                summary=None,
+            ),
+        ),
         dict(
             desc='Unset user auth type',
             command=('config_mod', [], dict(ipauserauthtype=None)),
@@ -312,4 +331,13 @@ class test_config(Declarative):
                 'value': None,
             },
         ),
+        dict(
+            desc='Set the value to the already set value, no modifications',
+            command=(
+                'config_mod', [], {
+                    'ipasearchrecordslimit': u'100',
+                },
+            ),
+            expected=errors.EmptyModlist(),
+        ),
     ]
