@@ -33,7 +33,7 @@ import pytest
 
 
 @pytest.fixture(scope='class')
-def user(request):
+def user(request, xmlrpc_setup):
     tracker = UserTracker(
         name=u'user1', givenname=u'Test', sn=u'User1',
         mail=[u'test1@example.com', u'test2@example.com']
