@@ -1587,7 +1587,8 @@ class TestAuthenticationIndicators(XMLRPC_test):
         indicators_service.update(
             updates={
                 u'krbprincipalauthind': [
-                    u'otp', u'radius', u'pkinit', u'hardened', u'idp'
+                    u'otp', u'radius', u'pkinit', u'hardened', u'idp',
+                    u'passkey',
                 ]
             }
         )
