@@ -31,6 +31,19 @@
 
 #include "ipa_krb5.h"
 
+#define TOSTR(x) STR(x)
+#define STR(x) #x
+const char *ipapwd_password_max_len_errmsg = \
+    "clear-text password is too long (max " \
+    TOSTR(IPAPWD_PASSWORD_MAX_LEN) \
+    " chars)!";
+
+/* Case-insensitive string values to by parsed as boolean true */
+static const char *const conf_yes[] = {
+    "y", "yes", "true", "t", "1", "on",
+    NULL,
+};
+
 /* Salt types */
 #define KRB5P_SALT_SIZE 16
 
@@ -125,6 +138,13 @@ krb5_error_code ipa_krb5_generate_key_data(krb5_context krbctx,
     int num_keys;
     int i;
 
+    if ((pwd.data != NULL) && (pwd.length > IPAPWD_PASSWORD_MAX_LEN)) {
+        kerr = E2BIG;
+        krb5_set_error_message(krbctx, kerr, "%s",
+                               ipapwd_password_max_len_errmsg);
+        return kerr;
+    }
+
     num_keys = num_encsalts;
     keys = calloc(num_keys, sizeof(krb5_key_data));
     if (!keys) {
@@ -554,7 +574,7 @@ int ber_decode_krb5_key_data(struct berval *encoded, int *m_kvno,
         retag = ber_peek_tag(be, &setlen);
         if (retag == (LBER_CONSTRUCTED | LBER_CLASS_CONTEXT | 2)) {
             /* not supported yet, skip */
-            retag = ber_scanf(be, "t[x]}");
+            retag = ber_scanf(be, "t[x]}", &tag);
         } else {
             retag = ber_scanf(be, "}");
         }
@@ -884,6 +904,7 @@ static int prep_ksdata(krb5_context krbctx, const char *str,
         ksdata = calloc(n + 1, sizeof(struct krb_key_salt));
         if (NULL == ksdata) {
             *err_msg = _("Out of memory!?\n");
+            ipa_krb5_free_ktypes(krbctx, ktypes);
             return 0;
         }
 
@@ -970,6 +991,10 @@ int create_keys(krb5_context krbctx,
     if (password) {
         key_password.data = password;
         key_password.length = strlen(password);
+        if (key_password.length > IPAPWD_PASSWORD_MAX_LEN) {
+            *err_msg = _("Password is too long!\n");
+            return 0;
+        }
 
         realm = krb5_princ_realm(krbctx, princ);
     }
@@ -1219,3 +1244,15 @@ done:
     }
     return ret;
 }
+
+bool ipa_krb5_parse_bool(const char *str)
+{
+    const char *const *p;
+
+    for (p = conf_yes; *p; p++) {
+        if (!strcasecmp(*p, str))
+            return true;
+    }
+
+    return false;
+}
